@@ -20,13 +20,14 @@
 #ifndef FST_DISAMBIGUATE_H_
 #define FST_DISAMBIGUATE_H_
 
+#include <cstdint>
 #include <list>
 #include <map>
+#include <memory>
 #include <set>
 #include <utility>
 #include <vector>
 
-#include <fst/types.h>
 
 #include <fst/arcsort.h>
 #include <fst/compose.h>
@@ -81,35 +82,30 @@ class RelationDeterminizeFilter {
   };
 
   explicit RelationDeterminizeFilter(const Fst<Arc> &fst)
-      : fst_(fst.Copy()), r_(new Relation()), s_(kNoStateId), head_(nullptr) {}
+      : fst_(fst.Copy()),
+        head_(nullptr),
+        r_(std::make_unique<Relation>()),
+        s_(kNoStateId) {}
 
-  // Ownership of the relation is given to this class.
-  RelationDeterminizeFilter(const Fst<Arc> &fst, Relation *r)
-      : fst_(fst.Copy()), r_(r), s_(kNoStateId), head_(0) {}
-
-  // Ownership of the relation is given to this class.
-  RelationDeterminizeFilter(const Fst<Arc> &fst, Relation *r,
-                            std::vector<StateId> *head)
-      : fst_(fst.Copy()), r_(r), s_(kNoStateId), head_(head) {}
+  RelationDeterminizeFilter(const Fst<Arc> &fst, std::unique_ptr<Relation> r,
+                            std::vector<StateId> *head = nullptr)
+      : fst_(fst.Copy()), head_(head), r_(std::move(r)), s_(kNoStateId) {}
 
   // This is needed, e.g., to go into the gallic domain for transducers.
-  // Ownership of the templated filter argument is given to this class.
   template <class Filter>
-  RelationDeterminizeFilter(const Fst<Arc> &fst, Filter *filter)
+  RelationDeterminizeFilter(const Fst<Arc> &fst, std::unique_ptr<Filter> filter)
       : fst_(fst.Copy()),
-        r_(new Relation(filter->GetRelation())),
-        s_(kNoStateId),
-        head_(filter->GetHeadStates()) {
-    delete filter;
-  }
+        head_(filter->GetHeadStates()),
+        r_(std::move(*filter).GetRelation()),
+        s_(kNoStateId) {}
 
   // Copy constructor; the FST can be passed if it has been deep-copied.
   RelationDeterminizeFilter(const RelationDeterminizeFilter &filter,
                             const Fst<Arc> *fst = nullptr)
       : fst_(fst ? fst->Copy() : filter.fst_->Copy()),
-        r_(new Relation(*filter.r_)),
-        s_(kNoStateId),
-        head_() {}
+        head_(nullptr) ,
+        r_(std::make_unique<Relation>(*filter.r_)),
+        s_(kNoStateId){}
 
   FilterState Start() const { return FilterState(fst_->Start()); }
 
@@ -136,11 +132,11 @@ class RelationDeterminizeFilter {
     return is_final_ ? final_weight : Weight::Zero();
   }
 
-  static uint64 Properties(uint64 props) {
+  static uint64_t Properties(uint64_t props) {
     return props & ~(kIDeterministic | kODeterministic);
   }
 
-  const Relation &GetRelation() { return *r_; }
+  std::unique_ptr<Relation> GetRelation() && { return std::move(r_); }
 
   std::vector<StateId> *GetHeadStates() { return head_; }
 
@@ -149,12 +145,12 @@ class RelationDeterminizeFilter {
   void InitLabelMap(LabelMap *label_map) const;
 
   std::unique_ptr<Fst<Arc>> fst_;  // Input FST.
+  std::vector<StateId> *head_;     // Head state for a given state,
+                                   // owned by the Disambiguator.
   std::unique_ptr<Relation> r_;    // Relation compatible with inv. trans. fnc.
   StateId s_;                      // Current state.
   const StateTuple *tuple_;        // Current tuple.
   bool is_final_;                  // Is the current head state final?
-  std::vector<StateId> *head_;     // Head state for a given state,
-                                   // owned by the Disambiguator.
 };
 
 template <class Arc, class Relation>
@@ -166,7 +162,7 @@ bool RelationDeterminizeFilter<Arc, Relation>::FilterArc(
   // Adds element to state tuple if element state is related to tuple head.
   for (auto liter = label_map->lower_bound(arc.ilabel);
        liter != label_map->end() && liter->first == arc.ilabel; ++liter) {
-    auto *dest_tuple = liter->second.dest_tuple;
+    const auto &dest_tuple = liter->second.dest_tuple;
     const auto dest_head = dest_tuple->filter_state.GetState();
     if ((*r_)(dest_element.state_id, dest_head)) {
       dest_tuple->subset.push_front(dest_element);
@@ -189,7 +185,7 @@ void RelationDeterminizeFilter<Arc, Relation>::InitLabelMap(
     if (arc.ilabel == label && arc.nextstate == nextstate) continue;
     DeterminizeArc<StateTuple> det_arc(arc);
     det_arc.dest_tuple->filter_state = FilterState(arc.nextstate);
-    label_map->emplace(arc.ilabel, det_arc);
+    label_map->emplace(arc.ilabel, std::move(det_arc));
     label = arc.ilabel;
     nextstate = arc.nextstate;
   }
@@ -234,7 +230,7 @@ class Disambiguator {
              (arc1.ilabel == arc2.ilabel && arc1.nextstate < arc2.nextstate);
     }
 
-    uint64 Properties(uint64 props) const {
+    uint64_t Properties(uint64_t props) const {
       return (props & kArcSortProperties) | kILabelSorted |
              (props & kAcceptor ? kOLabelSorted : 0);
     }
@@ -286,7 +282,7 @@ class Disambiguator {
       opts.state_table = new StateTable(*fsa, *fsa);
       const ComposeFst<Arc> cfst(*fsa, *fsa, opts);
       std::vector<bool> coaccess;
-      uint64 props = 0;
+      uint64_t props = 0;
       SccVisitor<Arc> scc_visitor(nullptr, nullptr, &coaccess, &props);
       DfsVisit(cfst, &scc_visitor);
       for (StateId s = 0; s < coaccess.size(); ++s) {
@@ -388,13 +384,12 @@ void Disambiguator<Arc>::PreDisambiguate(const ExpandedFst<Arc> &ifst,
   // Subset elements with states s1 and s2 (resp.) are in this relation iff they
   // there is a path from s1 to a final state that has the same label as some
   // path from s2 to a final state.
-  auto *common_future = new CommonFuture(ifst);
+  auto common_future = std::make_unique<CommonFuture>(ifst);
   DeterminizeFstOptions<Arc, CommonDivisor, Filter> nopts;
   nopts.delta = opts.delta;
   nopts.subsequential_label = opts.subsequential_label;
-  nopts.filter = new Filter(ifst, common_future, &head_);
-  // The filter takes ownership of 'common_future', and determinization takes
-  // ownership of the filter itself.
+  nopts.filter = new Filter(ifst, std::move(common_future), &head_);
+  // Determinization takes ownership of the filter itself.
   nopts.gc_limit = 0;  // Cache only the last state for fastest copy.
   if (opts.weight_threshold != Weight::Zero() ||
       opts.state_threshold != kNoStateId) {
