@@ -23,6 +23,7 @@
 #include <algorithm>
 #include <climits>
 #include <cmath>
+#include <cstdint>
 #include <cstring>
 #include <limits>
 #include <random>
@@ -30,14 +31,24 @@
 #include <string>
 #include <type_traits>
 
-#include <fst/types.h>
-
 #include <fst/util.h>
 #include <fst/weight.h>
 
+#include <fst/compat.h>
+#include <string_view>
 
 namespace fst {
 
+namespace internal {
+// TODO(wolfsonkin): Replace with `std::isnan` if and when that ends up
+// constexpr. For context, see
+// http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2020/p0533r6.pdf.
+template <class T>
+inline constexpr bool IsNan(T value) {
+  return value != value;
+}
+}  // namespace internal
+
 // Numeric limits class.
 template <class T>
 class FloatLimits {
@@ -61,13 +72,6 @@ class FloatWeightTpl {
 
   constexpr FloatWeightTpl(T f) : value_(f) {}  // NOLINT
 
-  // TODO(mjansche): Leave implicit once Android NDK r18 is the default.
-  FloatWeightTpl(const FloatWeightTpl &) = default;
-  FloatWeightTpl(FloatWeightTpl &&) noexcept = default;
-
-  FloatWeightTpl &operator=(const FloatWeightTpl &) = default;
-  FloatWeightTpl &operator=(FloatWeightTpl &&) noexcept = default;
-
   std::istream &Read(std::istream &strm) { return ReadType(strm, &value_); }
 
   std::ostream &Write(std::ostream &strm) const {
@@ -89,7 +93,7 @@ class FloatWeightTpl {
  protected:
   void SetValue(const T &f) { value_ = f; }
 
-  static constexpr const char *GetPrecisionString() {
+  static constexpr std::string_view GetPrecisionString() {
     return sizeof(T) == 4
                ? ""
                : sizeof(T) == 1
@@ -166,7 +170,7 @@ inline std::ostream &operator<<(std::ostream &strm,
     return strm << "Infinity";
   } else if (w.Value() == FloatLimits<T>::NegInfinity()) {
     return strm << "-Infinity";
-  } else if (w.Value() != w.Value()) {  // Fails for IEEE NaN.
+  } else if (internal::IsNan(w.Value())) {
     return strm << "BadNumber";
   } else {
     return strm << w.Value();
@@ -216,7 +220,7 @@ class TropicalWeightTpl : public FloatWeightTpl<T> {
 
   static const std::string &Type() {
     static const std::string *const type = new std::string(
-        std::string("tropical") + FloatWeightTpl<T>::GetPrecisionString());
+        fst::StrCat("tropical", FloatWeightTpl<T>::GetPrecisionString()));
     return *type;
   }
 
@@ -251,7 +255,7 @@ class TropicalWeightTpl : public FloatWeightTpl<T> {
 
   constexpr TropicalWeightTpl<T> Reverse() const { return *this; }
 
-  static constexpr uint64 Properties() {
+  static constexpr uint64_t Properties() {
     return kLeftSemiring | kRightSemiring | kCommutative | kPath | kIdempotent;
   }
 };
@@ -387,11 +391,11 @@ constexpr TropicalWeightTpl<double> Divide(const TropicalWeightTpl<double> &w1,
 // of Power<T, V> is made conditionally available only to that template
 // specialization.
 
-template <class T, class V, bool Enable = !std::is_same<V, size_t>::value,
-          typename std::enable_if<Enable>::type * = nullptr>
+template <class T, class V, bool Enable = !std::is_same_v<V, size_t>,
+          typename std::enable_if_t<Enable> * = nullptr>
 constexpr TropicalWeightTpl<T> Power(const TropicalWeightTpl<T> &w, V n) {
   using Weight = TropicalWeightTpl<T>;
-  return (!w.Member() || n != n)
+  return (!w.Member() || internal::IsNan(n))
              ? Weight::NoWeight()
              : (n == 0 || w == Weight::One()) ? Weight::One()
                                               : Weight(w.Value() * n);
@@ -433,7 +437,7 @@ class LogWeightTpl : public FloatWeightTpl<T> {
 
   static const std::string &Type() {
     static const std::string *const type = new std::string(
-        std::string("log") + FloatWeightTpl<T>::GetPrecisionString());
+        fst::StrCat("log", FloatWeightTpl<T>::GetPrecisionString()));
     return *type;
   }
 
@@ -452,7 +456,7 @@ class LogWeightTpl : public FloatWeightTpl<T> {
 
   constexpr LogWeightTpl<T> Reverse() const { return *this; }
 
-  static constexpr uint64 Properties() {
+  static constexpr uint64_t Properties() {
     return kLeftSemiring | kRightSemiring | kCommutative;
   }
 };
@@ -594,11 +598,11 @@ constexpr LogWeightTpl<double> Divide(const LogWeightTpl<double> &w1,
 
 // The comments for Power<>(Tropical...) above apply here unchanged.
 
-template <class T, class V, bool Enable = !std::is_same<V, size_t>::value,
-          typename std::enable_if<Enable>::type * = nullptr>
+template <class T, class V, bool Enable = !std::is_same_v<V, size_t>,
+          typename std::enable_if_t<Enable> * = nullptr>
 constexpr LogWeightTpl<T> Power(const LogWeightTpl<T> &w, V n) {
   using Weight = LogWeightTpl<T>;
-  return (!w.Member() || n != n)
+  return (!w.Member() || internal::IsNan(n))
              ? Weight::NoWeight()
              : (n == 0 || w == Weight::One()) ? Weight::One()
                                               : Weight(w.Value() * n);
@@ -676,7 +680,7 @@ class RealWeightTpl : public FloatWeightTpl<T> {
 
   static const std::string &Type() {
     static const std::string *const type = new std::string(
-        std::string("real") + FloatWeightTpl<T>::GetPrecisionString());
+        fst::StrCat("real", FloatWeightTpl<T>::GetPrecisionString()));
     return *type;
   }
 
@@ -695,7 +699,7 @@ class RealWeightTpl : public FloatWeightTpl<T> {
 
   constexpr RealWeightTpl<T> Reverse() const { return *this; }
 
-  static constexpr uint64 Properties() {
+  static constexpr uint64_t Properties() {
     return kLeftSemiring | kRightSemiring | kCommutative;
   }
 };
@@ -797,11 +801,11 @@ constexpr RealWeightTpl<double> Divide(const RealWeightTpl<double> &w1,
 
 // The comments for Power<>(Tropical...) above apply here unchanged.
 
-template <class T, class V, bool Enable = !std::is_same<V, size_t>::value,
-          typename std::enable_if<Enable>::type * = nullptr>
+template <class T, class V, bool Enable = !std::is_same_v<V, size_t>,
+          typename std::enable_if_t<Enable> * = nullptr>
 constexpr RealWeightTpl<T> Power(const RealWeightTpl<T> &w, V n) {
   using Weight = RealWeightTpl<T>;
-  return (!w.Member() || n != n)
+  return (!w.Member() || internal::IsNan(n))
              ? Weight::NoWeight()
              : (n == 0 || w == Weight::One()) ? Weight::One()
                                               : Weight(pow(w.Value(), n));
@@ -876,12 +880,12 @@ class MinMaxWeightTpl : public FloatWeightTpl<T> {
 
   static const std::string &Type() {
     static const std::string *const type = new std::string(
-        std::string("minmax") + FloatWeightTpl<T>::GetPrecisionString());
+        fst::StrCat("minmax", FloatWeightTpl<T>::GetPrecisionString()));
     return *type;
   }
 
   // Fails for IEEE NaN.
-  constexpr bool Member() const { return Value() == Value(); }
+  constexpr bool Member() const { return !internal::IsNan(Value()); }
 
   MinMaxWeightTpl<T> Quantize(float delta = kDelta) const {
     // If one of infinities, or a NaN.
@@ -895,7 +899,7 @@ class MinMaxWeightTpl : public FloatWeightTpl<T> {
 
   constexpr MinMaxWeightTpl<T> Reverse() const { return *this; }
 
-  static constexpr uint64 Properties() {
+  static constexpr uint64_t Properties() {
     return kLeftSemiring | kRightSemiring | kCommutative | kIdempotent | kPath;
   }
 };
@@ -1072,7 +1076,7 @@ template <class Weight>
 class FloatWeightGenerate {
  public:
   explicit FloatWeightGenerate(
-      uint64 seed = std::random_device()(), bool allow_zero = true,
+      uint64_t seed = std::random_device()(), bool allow_zero = true,
       const size_t num_random_weights = kNumRandomWeights)
       : rand_(seed),
         allow_zero_(allow_zero),
@@ -1098,7 +1102,7 @@ class WeightGenerate<TropicalWeightTpl<T>>
   using Weight = TropicalWeightTpl<T>;
   using Generate = FloatWeightGenerate<Weight>;
 
-  explicit WeightGenerate(uint64 seed = std::random_device()(),
+  explicit WeightGenerate(uint64_t seed = std::random_device()(),
                           bool allow_zero = true,
                           size_t num_random_weights = kNumRandomWeights)
       : Generate(seed, allow_zero, num_random_weights) {}
@@ -1113,7 +1117,7 @@ class WeightGenerate<LogWeightTpl<T>>
   using Weight = LogWeightTpl<T>;
   using Generate = FloatWeightGenerate<Weight>;
 
-  explicit WeightGenerate(uint64 seed = std::random_device()(),
+  explicit WeightGenerate(uint64_t seed = std::random_device()(),
                           bool allow_zero = true,
                           size_t num_random_weights = kNumRandomWeights)
       : Generate(seed, allow_zero, num_random_weights) {}
@@ -1128,7 +1132,7 @@ class WeightGenerate<RealWeightTpl<T>>
   using Weight = RealWeightTpl<T>;
   using Generate = FloatWeightGenerate<Weight>;
 
-  explicit WeightGenerate(uint64 seed = std::random_device()(),
+  explicit WeightGenerate(uint64_t seed = std::random_device()(),
                           bool allow_zero = true,
                           size_t num_random_weights = kNumRandomWeights)
       : Generate(seed, allow_zero, num_random_weights) {}
@@ -1145,7 +1149,7 @@ class WeightGenerate<MinMaxWeightTpl<T>> {
  public:
   using Weight = MinMaxWeightTpl<T>;
 
-  explicit WeightGenerate(uint64 seed = std::random_device()(),
+  explicit WeightGenerate(uint64_t seed = std::random_device()(),
                           bool allow_zero = true,
                           size_t num_random_weights = kNumRandomWeights)
       : rand_(seed),
