@@ -18,7 +18,11 @@
 #ifndef FST_GENERIC_REGISTER_H_
 #define FST_GENERIC_REGISTER_H_
 
+#include <functional>
+
 #include <fst/compat.h>
+#include <string_view>
+#include <fst/lock.h>
 #ifndef FST_NO_DYNAMIC_LINKING
 #include <dlfcn.h>
 #endif
@@ -33,8 +37,6 @@
 // KeyType must:
 //
 // * be such as can be stored as a key in a std::map<>.
-// * be concatenable with a const char* with the + operator
-//   (or you must subclass and redefine LoadEntryFromSharedObject)
 //
 // EntryType must be default constructible.
 //
@@ -44,10 +46,23 @@
 
 namespace fst {
 
+namespace internal {
+template <class T>
+struct KeyLookupReferenceType {
+  using type = const T &;
+};
+
+template <>
+struct KeyLookupReferenceType<std::string> {
+  using type = std::string_view;
+};
+}  // namespace internal
+
 template <class KeyType, class EntryType, class RegisterType>
 class GenericRegister {
  public:
   using Key = KeyType;
+  using KeyLookupRef = typename internal::KeyLookupReferenceType<KeyType>::type;
   using Entry = EntryType;
 
   static RegisterType *GetRegister() {
@@ -60,7 +75,7 @@ class GenericRegister {
     register_table_.emplace(key, entry);
   }
 
-  EntryType GetEntry(const KeyType &key) const {
+  EntryType GetEntry(KeyLookupRef key) const {
     const auto *entry = LookupEntry(key);
     if (entry) {
       return *entry;
@@ -74,7 +89,7 @@ class GenericRegister {
  protected:
   // Override this if you want to be able to load missing definitions from
   // shared object files.
-  virtual EntryType LoadEntryFromSharedObject(const KeyType &key) const {
+  virtual EntryType LoadEntryFromSharedObject(KeyLookupRef key) const {
 #ifdef FST_NO_DYNAMIC_LINKING
     return EntryType();
 #else
@@ -101,9 +116,9 @@ class GenericRegister {
   }
 
   // Override this to define how to turn a key into an SO filename.
-  virtual std::string ConvertKeyToSoFilename(const KeyType &key) const = 0;
+  virtual std::string ConvertKeyToSoFilename(KeyLookupRef key) const = 0;
 
-  virtual const EntryType *LookupEntry(const KeyType &key) const {
+  virtual const EntryType *LookupEntry(KeyLookupRef key) const {
     MutexLock l(&register_lock_);
     const auto it = register_table_.find(key);
     if (it != register_table_.end()) {
@@ -115,7 +130,7 @@ class GenericRegister {
 
  private:
   mutable Mutex register_lock_;
-  std::map<KeyType, EntryType> register_table_;
+  std::map<KeyType, EntryType, std::less<>> register_table_;
 };
 
 // Generic register-er class capable of creating new register entries in the
