@@ -24,11 +24,12 @@
 #ifndef FST_ICU_H_
 #define FST_ICU_H_
 
+#include <cstdint>
 #include <sstream>
 #include <vector>
 
-#include <fst/types.h>
 #include <fst/log.h>
+#include <string_view>
 
 namespace fst {
 
@@ -36,7 +37,7 @@ namespace fst {
 // if necessary. It is possible to use this sensibly with as little as 8 bits
 // of Label precision. This returns `true` deterministically for compatibility.
 template <class Label>
-bool ByteStringToLabels(const std::string &str, std::vector<Label> *labels) {
+bool ByteStringToLabels(std::string_view str, std::vector<Label> *labels) {
   for (const unsigned char ch : str) labels->push_back(ch);
   return true;
 }
@@ -48,7 +49,7 @@ bool ByteStringToLabels(const std::string &str, std::vector<Label> *labels) {
 // from the various Astral Planes. Naturally, it is safe to use this with larger
 // Labels (e.g., 64 bits).
 template <class Label>
-bool UTF8StringToLabels(const std::string &str, std::vector<Label> *labels) {
+bool UTF8StringToLabels(std::string_view str, std::vector<Label> *labels) {
   for (auto it = str.begin(); it != str.end();) {
     int c = *it & 0xff;
     ++it;
@@ -61,7 +62,7 @@ bool UTF8StringToLabels(const std::string &str, std::vector<Label> *labels) {
       }
       int count =
           (c >= 0xc0) + (c >= 0xe0) + (c >= 0xf0) + (c >= 0xf8) + (c >= 0xfc);
-      int32 label = c & ((1 << (6 - count)) - 1);
+      int32_t label = c & ((1 << (6 - count)) - 1);
       while (count != 0) {
         if (it == str.end()) {
           LOG(ERROR) << "UTF8StringToLabels: Truncated UTF-8 byte sequence";
@@ -100,7 +101,7 @@ bool LabelsToByteString(const std::vector<Label> &labels, std::string *str) {
 template <class Label>
 bool LabelsToUTF8String(const std::vector<Label> &labels, std::string *str) {
   std::ostringstream ostrm;
-  for (const int32 label : labels) {
+  for (const int32_t label : labels) {
     if (label < 0) {
       LOG(ERROR) << "LabelsToUTF8String: Invalid character found: " << label;
       return false;
