@@ -27,10 +27,10 @@
 #ifndef FST_LEXICOGRAPHIC_WEIGHT_H_
 #define FST_LEXICOGRAPHIC_WEIGHT_H_
 
+#include <cstdint>
 #include <random>
 #include <string>
 
-#include <fst/types.h>
 #include <fst/log.h>
 
 #include <fst/pair-weight.h>
@@ -102,7 +102,7 @@ class LexicographicWeight : public PairWeight<W1, W2> {
     return ReverseWeight(PairWeight<W1, W2>::Reverse());
   }
 
-  static constexpr uint64 Properties() {
+  static constexpr uint64_t Properties() {
     return W1::Properties() & W2::Properties() &
            (kLeftSemiring | kRightSemiring | kPath | kIdempotent |
             kCommutative);
@@ -151,7 +151,7 @@ class WeightGenerate<LexicographicWeight<W1, W2>> {
   using Generate1 = WeightGenerate<W1>;
   using Generate2 = WeightGenerate<W2>;
 
-  explicit WeightGenerate(uint64 seed = std::random_device()(),
+  explicit WeightGenerate(uint64_t seed = std::random_device()(),
                           bool allow_zero = true,
                           size_t num_random_weights = kNumRandomWeights)
       : rand_(seed),
