@@ -21,15 +21,17 @@
 #define FST_MATCHER_H_
 
 #include <algorithm>
+#include <cstdint>
 #include <memory>
+#include <tuple>
 #include <utility>
 
-#include <fst/types.h>
 #include <fst/log.h>
 
 #include <fst/mutable-fst.h>  // for all internal FST accessors.
 
 #include <unordered_map>
+#include <optional>
 
 namespace fst {
 
@@ -104,10 +106,10 @@ namespace fst {
 //
 //   // This specifies the known FST properties as viewed from this matcher. It
 //   // takes as argument the input FST's known properties.
-//   uint64 Properties(uint64 props) const override;
+//   uint64_t Properties(uint64_t props) const override;
 //
 //   // Returns matcher flags.
-//   uint32 Flags() const override;
+//   uint32_t Flags() const override;
 //
 //   // Returns matcher FST.
 //   const FST &GetFst() const override;
@@ -117,13 +119,13 @@ namespace fst {
 
 // Matcher needs to be used as the matching side in composition for
 // at least one state (has kRequirePriority).
-constexpr uint32 kRequireMatch = 0x00000001;
+inline constexpr uint32_t kRequireMatch = 0x00000001;
 
 // Flags used for basic matchers (see also lookahead.h).
-constexpr uint32 kMatcherFlags = kRequireMatch;
+inline constexpr uint32_t kMatcherFlags = kRequireMatch;
 
 // Matcher priority that is mandatory.
-constexpr ssize_t kRequirePriority = -1;
+inline constexpr ssize_t kRequirePriority = -1;
 
 // Matcher interface, templated on the Arc definition; used for matcher
 // specializations that are returned by the InitMatcher FST method.
@@ -147,11 +149,11 @@ class MatcherBase {
   virtual const Arc &Value() const = 0;
   virtual void Next() = 0;
   virtual const Fst<Arc> &GetFst() const = 0;
-  virtual uint64 Properties(uint64) const = 0;
+  virtual uint64_t Properties(uint64_t) const = 0;
 
   // Trivial implementations that can be used by derived classes. Full
   // devirtualization is expected for any derived class marked final.
-  virtual uint32 Flags() const { return 0; }
+  virtual uint32_t Flags() const { return 0; }
 
   virtual Weight Final(StateId s) const { return internal::Final(GetFst(), s); }
 
@@ -189,14 +191,13 @@ class SortedMatcher : public MatcherBase<typename F::Arc> {
   SortedMatcher(const FST *fst, MatchType match_type, Label binary_label = 1)
       : fst_(*fst),
         state_(kNoStateId),
-        aiter_(nullptr),
+        aiter_(std::nullopt),
         match_type_(match_type),
         binary_label_(binary_label),
         match_label_(kNoLabel),
         narcs_(0),
         loop_(kNoLabel, 0, Weight::One(), kNoStateId),
-        error_(false),
-        aiter_pool_(1) {
+        error_(false) {
     switch (match_type_) {
       case MATCH_INPUT:
       case MATCH_NONE:
@@ -216,16 +217,15 @@ class SortedMatcher : public MatcherBase<typename F::Arc> {
       : owned_fst_(matcher.fst_.Copy(safe)),
         fst_(*owned_fst_),
         state_(kNoStateId),
-        aiter_(nullptr),
+        aiter_(std::nullopt),
         match_type_(matcher.match_type_),
         binary_label_(matcher.binary_label_),
         match_label_(kNoLabel),
         narcs_(0),
         loop_(matcher.loop_),
-        error_(matcher.error_),
-        aiter_pool_(1) {}
+        error_(matcher.error_) {}
 
-  ~SortedMatcher() override { Destroy(aiter_, &aiter_pool_); }
+  ~SortedMatcher() override = default;
 
   SortedMatcher *Copy(bool safe = false) const override {
     return new SortedMatcher(*this, safe);
@@ -254,8 +254,7 @@ class SortedMatcher : public MatcherBase<typename F::Arc> {
       FSTERROR() << "SortedMatcher: Bad match type";
       error_ = true;
     }
-    Destroy(aiter_, &aiter_pool_);
-    aiter_ = new (&aiter_pool_) ArcIterator<FST>(fst_, s);
+    aiter_.emplace(fst_, s);
     aiter_->SetFlags(kArcNoCache, kArcNoCache);
     narcs_ = internal::NumArcs(fst_, s);
     loop_.nextstate = s;
@@ -322,7 +321,7 @@ class SortedMatcher : public MatcherBase<typename F::Arc> {
 
   const FST &GetFst() const override { return fst_; }
 
-  uint64 Properties(uint64 inprops) const override {
+  uint64_t Properties(uint64_t inprops) const override {
     return inprops | (error_ ? kError : 0);
   }
 
@@ -341,16 +340,16 @@ class SortedMatcher : public MatcherBase<typename F::Arc> {
   std::unique_ptr<const FST> owned_fst_;  // FST ptr if owned.
   const FST &fst_;                        // FST for matching.
   StateId state_;                         // Matcher state.
-  ArcIterator<FST> *aiter_;               // Iterator for current state.
-  MatchType match_type_;                  // Type of match to perform.
-  Label binary_label_;                    // Least label for binary search.
-  Label match_label_;                     // Current label to be matched.
-  size_t narcs_;                          // Current state arc count.
-  Arc loop_;                              // For non-consuming symbols.
-  bool current_loop_;                     // Current arc is the implicit loop.
-  bool exact_match_;                      // Exact match or lower bound?
-  bool error_;                            // Error encountered?
-  MemoryPool<ArcIterator<FST>> aiter_pool_;  // Pool of arc iterators.
+  mutable std::optional<ArcIterator<FST>>
+      aiter_;             // Iterator for current state.
+  MatchType match_type_;  // Type of match to perform.
+  Label binary_label_;    // Least label for binary search.
+  Label match_label_;     // Current label to be matched.
+  size_t narcs_;          // Current state arc count.
+  Arc loop_;              // For non-consuming symbols.
+  bool current_loop_;     // Current arc is the implicit loop.
+  bool exact_match_;      // Exact match or lower bound?
+  bool error_;            // Error encountered?
 };
 
 // Returns true iff match to match_label_. The arc iterator is positioned at the
@@ -506,7 +505,7 @@ class HashMatcher : public MatcherBase<typename F::Arc> {
 
   const FST &GetFst() const override { return fst_; }
 
-  uint64 Properties(uint64 inprops) const override {
+  uint64_t Properties(uint64_t inprops) const override {
     return inprops | (error_ ? kError : 0);
   }
 
@@ -547,12 +546,12 @@ void HashMatcher<FST>::SetState(typename FST::Arc::StateId s) {
     error_ = true;
   }
   // Attempts to insert a new label table.
-  auto it_and_success = state_table_->emplace(
-      state_, std::make_unique<LabelTable>());
+  const auto &[it, success] =
+      state_table_->emplace(state_, std::make_unique<LabelTable>());
   // Sets instance's pointer to the label table for this state.
-  label_table_ = it_and_success.first->second.get();
+  label_table_ = it->second.get();
   // If it already exists, no additional work is done and we simply return.
-  if (!it_and_success.second) return;
+  if (!success) return;
   // Otherwise, populate this new table.
   // Populates the label table.
   label_table_->reserve(internal::NumArcs(fst_, state_));
@@ -568,9 +567,7 @@ void HashMatcher<FST>::SetState(typename FST::Arc::StateId s) {
 
 template <class FST>
 inline bool HashMatcher<FST>::Search(typename FST::Arc::Label match_label) {
-  auto range = label_table_->equal_range(match_label);
-  label_it_ = range.first;
-  label_end_ = range.second;
+  std::tie(label_it_, label_end_) = label_table_->equal_range(match_label);
   if (label_it_ == label_end_) return false;
   aiter_->Seek(label_it_->second);
   return true;
@@ -727,9 +724,9 @@ class PhiMatcher : public MatcherBase<typename M::Arc> {
 
   const FST &GetFst() const override { return matcher_->GetFst(); }
 
-  uint64 Properties(uint64 props) const override;
+  uint64_t Properties(uint64_t props) const override;
 
-  uint32 Flags() const override {
+  uint32_t Flags() const override {
     if (phi_label_ == kNoLabel || match_type_ == MATCH_NONE) {
       return matcher_->Flags();
     }
@@ -804,7 +801,7 @@ inline bool PhiMatcher<M>::Find(Label label) {
 }
 
 template <class M>
-inline uint64 PhiMatcher<M>::Properties(uint64 inprops) const {
+inline uint64_t PhiMatcher<M>::Properties(uint64_t inprops) const {
   auto outprops = matcher_->Properties(inprops);
   if (error_) outprops |= kError;
   if (match_type_ == MATCH_NONE) {
@@ -979,9 +976,9 @@ class RhoMatcher : public MatcherBase<typename M::Arc> {
 
   const FST &GetFst() const override { return matcher_->GetFst(); }
 
-  uint64 Properties(uint64 props) const override;
+  uint64_t Properties(uint64_t props) const override;
 
-  uint32 Flags() const override {
+  uint32_t Flags() const override {
     if (rho_label_ == kNoLabel || match_type_ == MATCH_NONE) {
       return matcher_->Flags();
     }
@@ -1003,7 +1000,7 @@ class RhoMatcher : public MatcherBase<typename M::Arc> {
 };
 
 template <class M>
-inline uint64 RhoMatcher<M>::Properties(uint64 inprops) const {
+inline uint64_t RhoMatcher<M>::Properties(uint64_t inprops) const {
   auto outprops = matcher_->Properties(inprops);
   if (error_) outprops |= kError;
   if (match_type_ == MATCH_NONE) {
@@ -1175,9 +1172,9 @@ class SigmaMatcher : public MatcherBase<typename M::Arc> {
 
   const FST &GetFst() const override { return matcher_->GetFst(); }
 
-  uint64 Properties(uint64 props) const override;
+  uint64_t Properties(uint64_t props) const override;
 
-  uint32 Flags() const override {
+  uint32_t Flags() const override {
     if (sigma_label_ == kNoLabel || match_type_ == MATCH_NONE) {
       return matcher_->Flags();
     }
@@ -1200,7 +1197,7 @@ class SigmaMatcher : public MatcherBase<typename M::Arc> {
 };
 
 template <class M>
-inline uint64 SigmaMatcher<M>::Properties(uint64 inprops) const {
+inline uint64_t SigmaMatcher<M>::Properties(uint64_t inprops) const {
   auto outprops = matcher_->Properties(inprops);
   if (error_) outprops |= kError;
   if (match_type_ == MATCH_NONE) {
@@ -1227,10 +1224,10 @@ inline uint64 SigmaMatcher<M>::Properties(uint64 inprops) const {
 // Flags for MultiEpsMatcher.
 
 // Return multi-epsilon arcs for Find(kNoLabel).
-const uint32 kMultiEpsList = 0x00000001;
+inline constexpr uint32_t kMultiEpsList = 0x00000001;
 
 // Return a kNolabel loop for Find(multi_eps).
-const uint32 kMultiEpsLoop = 0x00000002;
+inline constexpr uint32_t kMultiEpsLoop = 0x00000002;
 
 // MultiEpsMatcher: allows treating multiple non-0 labels as
 // non-consuming labels in addition to 0 that is always
@@ -1250,7 +1247,7 @@ class MultiEpsMatcher {
 
   // This makes a copy of the FST (w/o 'matcher' arg).
   MultiEpsMatcher(const FST &fst, MatchType match_type,
-                  uint32 flags = (kMultiEpsLoop | kMultiEpsList),
+                  uint32_t flags = (kMultiEpsLoop | kMultiEpsList),
                   M *matcher = nullptr, bool own_matcher = true)
       : matcher_(matcher ? matcher : new M(fst, match_type)),
         flags_(flags),
@@ -1260,7 +1257,7 @@ class MultiEpsMatcher {
 
   // This doesn't copy the FST.
   MultiEpsMatcher(const FST *fst, MatchType match_type,
-                  uint32 flags = (kMultiEpsLoop | kMultiEpsList),
+                  uint32_t flags = (kMultiEpsLoop | kMultiEpsList),
                   M *matcher = nullptr, bool own_matcher = true)
       : matcher_(matcher ? matcher : new M(fst, match_type)),
         flags_(flags),
@@ -1322,13 +1319,15 @@ class MultiEpsMatcher {
 
   const FST &GetFst() const { return matcher_->GetFst(); }
 
-  uint64 Properties(uint64 props) const { return matcher_->Properties(props); }
+  uint64_t Properties(uint64_t props) const {
+    return matcher_->Properties(props);
+  }
 
   const M *GetMatcher() const { return matcher_; }
 
   Weight Final(StateId s) const { return matcher_->Final(s); }
 
-  uint32 Flags() const { return matcher_->Flags(); }
+  uint32_t Flags() const { return matcher_->Flags(); }
 
   ssize_t Priority(StateId s) { return matcher_->Priority(s); }
 
@@ -1364,7 +1363,7 @@ class MultiEpsMatcher {
   }
 
   M *matcher_;
-  uint32 flags_;
+  uint32_t flags_;
   bool own_matcher_;  // Does this class delete the matcher?
 
   // Multi-eps label set.
@@ -1477,13 +1476,13 @@ class ExplicitMatcher : public MatcherBase<typename M::Arc> {
 
   const FST &GetFst() const final { return matcher_->GetFst(); }
 
-  uint64 Properties(uint64 inprops) const override {
+  uint64_t Properties(uint64_t inprops) const override {
     return matcher_->Properties(inprops);
   }
 
   const M *GetMatcher() const { return matcher_.get(); }
 
-  uint32 Flags() const override { return matcher_->Flags(); }
+  uint32_t Flags() const override { return matcher_->Flags(); }
 
  private:
   // Checks current arc if available and explicit. If not available, stops. If
@@ -1556,13 +1555,13 @@ class Matcher {
 
   void Next() { base_->Next(); }
 
-  const FST &GetFst() const { return fst::down_cast<const FST &>(base_->GetFst()); }
+  const FST &GetFst() const { return down_cast<const FST &>(base_->GetFst()); }
 
-  uint64 Properties(uint64 props) const { return base_->Properties(props); }
+  uint64_t Properties(uint64_t props) const { return base_->Properties(props); }
 
   Weight Final(StateId s) const { return base_->Final(s); }
 
-  uint32 Flags() const { return base_->Flags() & kMatcherFlags; }
+  uint32_t Flags() const { return base_->Flags() & kMatcherFlags; }
 
   ssize_t Priority(StateId s) { return base_->Priority(s); }
 
