@@ -32,10 +32,10 @@
 namespace fst {
 
 // Default block allocation size.
-constexpr int kAllocSize = 64;
+inline constexpr int kAllocSize = 64;
 
 // Minimum number of allocations per block.
-constexpr int kAllocFit = 4;
+inline constexpr int kAllocFit = 4;
 
 // Base class for MemoryArena that allows (e.g.) MemoryArenaCollection to
 // easily manipulate collections of variously sized arenas.
@@ -54,24 +54,27 @@ namespace internal {
 template <size_t object_size>
 class MemoryArenaImpl : public MemoryArenaBase {
  public:
-  enum { kObjectSize = object_size };
+  static constexpr size_t kObjectSize = object_size;
 
   explicit MemoryArenaImpl(size_t block_size = kAllocSize)
       : block_size_(block_size * kObjectSize), block_pos_(0) {
-    blocks_.emplace_front(std::make_unique<std::byte[]>(block_size_));
+    blocks_.push_front(
+        fst::make_unique_for_overwrite<std::byte[]>(block_size_));
   }
 
   void *Allocate(size_t size) {
     const auto byte_size = size * kObjectSize;
     if (byte_size * kAllocFit > block_size_) {
       // Large block; adds new large block.
-      blocks_.emplace_back(std::make_unique<std::byte[]>(byte_size));
+      blocks_.push_back(
+          fst::make_unique_for_overwrite<std::byte[]>(byte_size));
       return blocks_.back().get();
-  }
+    }
     if (block_pos_ + byte_size > block_size_) {
       // Doesn't fit; adds new standard block.
       block_pos_ = 0;
-      blocks_.emplace_front(std::make_unique<std::byte[]>(block_size_));
+      blocks_.push_front(
+          fst::make_unique_for_overwrite<std::byte[]>(block_size_));
     }
     // Fits; uses current block.
     auto *ptr = &blocks_.front()[block_pos_];
@@ -109,7 +112,7 @@ namespace internal {
 template <size_t object_size>
 class MemoryPoolImpl : public MemoryPoolBase {
  public:
-  enum { kObjectSize = object_size };
+  static constexpr size_t kObjectSize = object_size;
 
   struct Link {
     std::byte buf[kObjectSize];
@@ -120,15 +123,15 @@ class MemoryPoolImpl : public MemoryPoolBase {
       : mem_arena_(pool_size), free_list_(nullptr) {}
 
   void *Allocate() {
+    Link *link;
     if (free_list_ == nullptr) {
-      auto *link = static_cast<Link *>(mem_arena_.Allocate(1));
+      link = static_cast<Link *>(mem_arena_.Allocate(1));
       link->next = nullptr;
-      return link;
     } else {
-      auto *link = free_list_;
+      link = free_list_;
       free_list_ = link->next;
-      return link;
     }
+    return fst::implicit_cast<std::byte *>(link->buf);
   }
 
   void Free(void *ptr) {
@@ -179,7 +182,7 @@ class MemoryArenaCollection {
     if (arena == nullptr) {
       arena = std::make_unique<MemoryArena<T>>(block_size_);
     }
-    return static_cast<MemoryArena<T> *>(arena.get());
+    return down_cast<MemoryArena<T> *>(arena.get());
   }
 
   size_t BlockSize() const { return block_size_; }
@@ -201,7 +204,7 @@ class MemoryPoolCollection {
     if (sizeof(T) >= pools_.size()) pools_.resize(sizeof(T) + 1);
     auto &pool = pools_[sizeof(T)];
     if (pool == nullptr) pool = std::make_unique<MemoryPool<T>>(pool_size_);
-    return static_cast<MemoryPool<T> *>(pool.get());
+    return down_cast<MemoryPool<T> *>(pool.get());
   }
 
   size_t PoolSize() const { return pool_size_; }
@@ -225,55 +228,24 @@ class BlockAllocator {
  public:
   using Allocator = std::allocator<T>;
   using size_type = typename Allocator::size_type;
-  using difference_type = typename Allocator::difference_type;
-  using pointer = typename Allocator::pointer;
-  using const_pointer = typename Allocator::const_pointer;
-  using reference = typename Allocator::reference;
-  using const_reference = typename Allocator::const_reference;
   using value_type = typename Allocator::value_type;
 
-  template <typename U>
-  struct rebind {
-    using other = BlockAllocator<U>;
-  };
-
   explicit BlockAllocator(size_t block_size = kAllocSize)
       : arenas_(std::make_shared<MemoryArenaCollection>(block_size)) {}
 
-  ~BlockAllocator() = default;
-  BlockAllocator(const BlockAllocator &) = default;
-  BlockAllocator(BlockAllocator &&) = default;
-  BlockAllocator &operator=(const BlockAllocator &) = default;
-  BlockAllocator &operator=(BlockAllocator &&) = default;
-
   template <typename U>
   explicit BlockAllocator(const BlockAllocator<U> &arena_alloc)
       : arenas_(arena_alloc.Arenas()) {}
 
-  pointer address(reference ref) const { return Allocator().address(ref); }
-
-  const_pointer address(const_reference ref) const {
-    return Allocator().address(ref);
-  }
-
-  size_type max_size() const { return Allocator().max_size(); }
-
-  template <class U, class... Args>
-  void construct(U *p, Args &&... args) {
-    Allocator().construct(p, std::forward<Args>(args)...);
-  }
-
-  void destroy(pointer p) { Allocator().destroy(p); }
-
-  pointer allocate(size_type n, const void *hint = nullptr) {
+  T *allocate(size_type n, const void *hint = nullptr) {
     if (n * kAllocFit <= kAllocSize) {
-      return static_cast<pointer>(Arena()->Allocate(n));
+      return static_cast<T *>(Arena()->Allocate(n));
     } else {
       return Allocator().allocate(n, hint);
     }
   }
 
-  void deallocate(pointer p, size_type n) {
+  void deallocate(T *p, size_type n) {
     if (n * kAllocFit > kAllocSize) Allocator().deallocate(p, n);
   }
 
@@ -310,67 +282,36 @@ class PoolAllocator {
  public:
   using Allocator = std::allocator<T>;
   using size_type = typename Allocator::size_type;
-  using difference_type = typename Allocator::difference_type;
-  using pointer = typename Allocator::pointer;
-  using const_pointer = typename Allocator::const_pointer;
-  using reference = typename Allocator::reference;
-  using const_reference = typename Allocator::const_reference;
   using value_type = typename Allocator::value_type;
 
-  template <typename U>
-  struct rebind {
-    using other = PoolAllocator<U>;
-  };
-
   explicit PoolAllocator(size_t pool_size = kAllocSize)
       : pools_(std::make_shared<MemoryPoolCollection>(pool_size)) {}
 
-  ~PoolAllocator() = default;
-  PoolAllocator(const PoolAllocator &) = default;
-  PoolAllocator(PoolAllocator &&) = default;
-  PoolAllocator &operator=(const PoolAllocator &) = default;
-  PoolAllocator &operator=(PoolAllocator &&) = default;
-
   template <typename U>
   explicit PoolAllocator(const PoolAllocator<U> &pool_alloc)
       : pools_(pool_alloc.Pools()) {}
 
-  pointer address(reference ref) const { return Allocator().address(ref); }
-
-  const_pointer address(const_reference ref) const {
-    return Allocator().address(ref);
-  }
-
-  size_type max_size() const { return Allocator().max_size(); }
-
-  template <class U, class... Args>
-  void construct(U *p, Args &&... args) {
-    Allocator().construct(p, std::forward<Args>(args)...);
-  }
-
-  void destroy(pointer p) { Allocator().destroy(p); }
-
-  pointer allocate(size_type n, const void *hint = nullptr) {
+  T *allocate(size_type n, const void *hint = nullptr) {
     if (n == 1) {
-      return static_cast<pointer>(Pool<1>()->Allocate());
+      return static_cast<T *>(Pool<1>()->Allocate());
     } else if (n == 2) {
-      return static_cast<pointer>(Pool<2>()->Allocate());
+      return static_cast<T *>(Pool<2>()->Allocate());
     } else if (n <= 4) {
-      return static_cast<pointer>(Pool<4>()->Allocate());
+      return static_cast<T *>(Pool<4>()->Allocate());
     } else if (n <= 8) {
-      return static_cast<pointer>(Pool<8>()->Allocate());
+      return static_cast<T *>(Pool<8>()->Allocate());
     } else if (n <= 16) {
-      return static_cast<pointer>(Pool<16>()->Allocate());
+      return static_cast<T *>(Pool<16>()->Allocate());
     } else if (n <= 32) {
-      return static_cast<pointer>(Pool<32>()->Allocate());
+      return static_cast<T *>(Pool<32>()->Allocate());
     } else if (n <= 64) {
-      return static_cast<pointer>(Pool<64>()->Allocate());
+      return static_cast<T *>(Pool<64>()->Allocate());
     } else {
       return Allocator().allocate(n, hint);
     }
   }
 
-  void deallocate(pointer p, size_type n) {
+  void deallocate(T *p, size_type n) {
     if (n == 1) {
       Pool<1>()->Free(p);
     } else if (n == 2) {
