@@ -22,11 +22,12 @@
 
 #include <sys/types.h>
 
+#include <cstdint>
 #include <vector>
 
 #include <fst/compat.h>
-#include <fst/types.h>
 #include <fst/log.h>
+#include <string_view>
 
 namespace fst {
 
@@ -41,13 +42,13 @@ namespace fst {
 // true. If it is not set, the property is false.
 
 // The Fst is an ExpandedFst.
-constexpr uint64 kExpanded = 0x0000000000000001ULL;
+inline constexpr uint64_t kExpanded = 0x0000000000000001ULL;
 
 // The Fst is a MutableFst.
-constexpr uint64 kMutable = 0x0000000000000002ULL;
+inline constexpr uint64_t kMutable = 0x0000000000000002ULL;
 
 // An error was detected while constructing/using the FST.
-constexpr uint64 kError = 0x0000000000000004ULL;
+inline constexpr uint64_t kError = 0x0000000000000004ULL;
 
 // TRINARY PROPERTIES
 //
@@ -59,106 +60,106 @@ constexpr uint64 kError = 0x0000000000000004ULL;
 // positive bit at an odd and lower position.
 
 // ilabel == olabel for each arc.
-constexpr uint64 kAcceptor = 0x0000000000010000ULL;
+inline constexpr uint64_t kAcceptor = 0x0000000000010000ULL;
 // ilabel != olabel for some arc.
-constexpr uint64 kNotAcceptor = 0x0000000000020000ULL;
+inline constexpr uint64_t kNotAcceptor = 0x0000000000020000ULL;
 
 // ilabels unique leaving each state.
-constexpr uint64 kIDeterministic = 0x0000000000040000ULL;
+inline constexpr uint64_t kIDeterministic = 0x0000000000040000ULL;
 // ilabels not unique leaving some state.
-constexpr uint64 kNonIDeterministic = 0x0000000000080000ULL;
+inline constexpr uint64_t kNonIDeterministic = 0x0000000000080000ULL;
 
 // olabels unique leaving each state.
-constexpr uint64 kODeterministic = 0x0000000000100000ULL;
+inline constexpr uint64_t kODeterministic = 0x0000000000100000ULL;
 // olabels not unique leaving some state.
-constexpr uint64 kNonODeterministic = 0x0000000000200000ULL;
+inline constexpr uint64_t kNonODeterministic = 0x0000000000200000ULL;
 
 // FST has input/output epsilons.
-constexpr uint64 kEpsilons = 0x0000000000400000ULL;
+inline constexpr uint64_t kEpsilons = 0x0000000000400000ULL;
 // FST has no input/output epsilons.
-constexpr uint64 kNoEpsilons = 0x0000000000800000ULL;
+inline constexpr uint64_t kNoEpsilons = 0x0000000000800000ULL;
 
 // FST has input epsilons.
-constexpr uint64 kIEpsilons = 0x0000000001000000ULL;
+inline constexpr uint64_t kIEpsilons = 0x0000000001000000ULL;
 // FST has no input epsilons.
-constexpr uint64 kNoIEpsilons = 0x0000000002000000ULL;
+inline constexpr uint64_t kNoIEpsilons = 0x0000000002000000ULL;
 
 // FST has output epsilons.
-constexpr uint64 kOEpsilons = 0x0000000004000000ULL;
+inline constexpr uint64_t kOEpsilons = 0x0000000004000000ULL;
 // FST has no output epsilons.
-constexpr uint64 kNoOEpsilons = 0x0000000008000000ULL;
+inline constexpr uint64_t kNoOEpsilons = 0x0000000008000000ULL;
 
 // ilabels sorted wrt < for each state.
-constexpr uint64 kILabelSorted = 0x0000000010000000ULL;
+inline constexpr uint64_t kILabelSorted = 0x0000000010000000ULL;
 // ilabels not sorted wrt < for some state.
-constexpr uint64 kNotILabelSorted = 0x0000000020000000ULL;
+inline constexpr uint64_t kNotILabelSorted = 0x0000000020000000ULL;
 
 // olabels sorted wrt < for each state.
-constexpr uint64 kOLabelSorted = 0x0000000040000000ULL;
+inline constexpr uint64_t kOLabelSorted = 0x0000000040000000ULL;
 // olabels not sorted wrt < for some state.
-constexpr uint64 kNotOLabelSorted = 0x0000000080000000ULL;
+inline constexpr uint64_t kNotOLabelSorted = 0x0000000080000000ULL;
 
 // Non-trivial arc or final weights.
-constexpr uint64 kWeighted = 0x0000000100000000ULL;
+inline constexpr uint64_t kWeighted = 0x0000000100000000ULL;
 // Only trivial arc and final weights.
-constexpr uint64 kUnweighted = 0x0000000200000000ULL;
+inline constexpr uint64_t kUnweighted = 0x0000000200000000ULL;
 
 // FST has cycles.
-constexpr uint64 kCyclic = 0x0000000400000000ULL;
+inline constexpr uint64_t kCyclic = 0x0000000400000000ULL;
 // FST has no cycles.
-constexpr uint64 kAcyclic = 0x0000000800000000ULL;
+inline constexpr uint64_t kAcyclic = 0x0000000800000000ULL;
 
 // FST has cycles containing the initial state.
-constexpr uint64 kInitialCyclic = 0x0000001000000000ULL;
+inline constexpr uint64_t kInitialCyclic = 0x0000001000000000ULL;
 // FST has no cycles containing the initial state.
-constexpr uint64 kInitialAcyclic = 0x0000002000000000ULL;
+inline constexpr uint64_t kInitialAcyclic = 0x0000002000000000ULL;
 
 // FST is topologically sorted.
-constexpr uint64 kTopSorted = 0x0000004000000000ULL;
+inline constexpr uint64_t kTopSorted = 0x0000004000000000ULL;
 // FST is not topologically sorted.
-constexpr uint64 kNotTopSorted = 0x0000008000000000ULL;
+inline constexpr uint64_t kNotTopSorted = 0x0000008000000000ULL;
 
 // All states reachable from the initial state.
-constexpr uint64 kAccessible = 0x0000010000000000ULL;
+inline constexpr uint64_t kAccessible = 0x0000010000000000ULL;
 // Not all states reachable from the initial state.
-constexpr uint64 kNotAccessible = 0x0000020000000000ULL;
+inline constexpr uint64_t kNotAccessible = 0x0000020000000000ULL;
 
 // All states can reach a final state.
-constexpr uint64 kCoAccessible = 0x0000040000000000ULL;
+inline constexpr uint64_t kCoAccessible = 0x0000040000000000ULL;
 // Not all states can reach a final state.
-constexpr uint64 kNotCoAccessible = 0x0000080000000000ULL;
+inline constexpr uint64_t kNotCoAccessible = 0x0000080000000000ULL;
 
 // If NumStates() > 0, then state 0 is initial, state NumStates() - 1 is final,
 // there is a transition from each non-final state i to state i + 1, and there
 // are no other transitions.
-constexpr uint64 kString = 0x0000100000000000ULL;
+inline constexpr uint64_t kString = 0x0000100000000000ULL;
 
 // Not a string FST.
-constexpr uint64 kNotString = 0x0000200000000000ULL;
+inline constexpr uint64_t kNotString = 0x0000200000000000ULL;
 
 // FST has at least one weighted cycle.
-constexpr uint64 kWeightedCycles = 0x0000400000000000ULL;
+inline constexpr uint64_t kWeightedCycles = 0x0000400000000000ULL;
 
 // FST has no weighted cycles. Any cycles that may be present are unweighted.
-constexpr uint64 kUnweightedCycles = 0x0000800000000000ULL;
+inline constexpr uint64_t kUnweightedCycles = 0x0000800000000000ULL;
 
 // COMPOSITE PROPERTIES
 
 // Properties of an empty machine.
-constexpr uint64 kNullProperties =
+inline constexpr uint64_t kNullProperties =
     kAcceptor | kIDeterministic | kODeterministic | kNoEpsilons | kNoIEpsilons |
     kNoOEpsilons | kILabelSorted | kOLabelSorted | kUnweighted | kAcyclic |
     kInitialAcyclic | kTopSorted | kAccessible | kCoAccessible | kString |
     kUnweightedCycles;
 
 // Properties of a string FST compiled into a string.
-constexpr uint64 kCompiledStringProperties =
+inline constexpr uint64_t kCompiledStringProperties =
     kAcceptor | kString | kUnweighted | kIDeterministic | kODeterministic |
     kILabelSorted | kOLabelSorted | kAcyclic | kInitialAcyclic |
     kUnweightedCycles | kTopSorted | kAccessible | kCoAccessible;
 
 // Properties that are preserved when an FST is copied.
-constexpr uint64 kCopyProperties =
+inline constexpr uint64_t kCopyProperties =
     kError | kAcceptor | kNotAcceptor | kIDeterministic | kNonIDeterministic |
     kODeterministic | kNonODeterministic | kEpsilons | kNoEpsilons |
     kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons | kILabelSorted |
@@ -169,7 +170,7 @@ constexpr uint64 kCopyProperties =
     kUnweightedCycles;
 
 // Properties that are intrinsic to the FST.
-constexpr uint64 kIntrinsicProperties =
+inline constexpr uint64_t kIntrinsicProperties =
     kExpanded | kMutable | kAcceptor | kNotAcceptor | kIDeterministic |
     kNonIDeterministic | kODeterministic | kNonODeterministic | kEpsilons |
     kNoEpsilons | kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons |
@@ -180,10 +181,10 @@ constexpr uint64 kIntrinsicProperties =
     kWeightedCycles | kUnweightedCycles;
 
 // Properties that are (potentially) extrinsic to the FST.
-constexpr uint64 kExtrinsicProperties = kError;
+inline constexpr uint64_t kExtrinsicProperties = kError;
 
 // Properties that are preserved when an FST start state is set.
-constexpr uint64 kSetStartProperties =
+inline constexpr uint64_t kSetStartProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor | kIDeterministic |
     kNonIDeterministic | kODeterministic | kNonODeterministic | kEpsilons |
     kNoEpsilons | kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons |
@@ -192,7 +193,7 @@ constexpr uint64 kSetStartProperties =
     kCoAccessible | kNotCoAccessible | kWeightedCycles | kUnweightedCycles;
 
 // Properties that are preserved when an FST final weight is set.
-constexpr uint64 kSetFinalProperties =
+inline constexpr uint64_t kSetFinalProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor | kIDeterministic |
     kNonIDeterministic | kODeterministic | kNonODeterministic | kEpsilons |
     kNoEpsilons | kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons |
@@ -202,7 +203,7 @@ constexpr uint64 kSetFinalProperties =
     kUnweightedCycles;
 
 // Properties that are preserved when an FST state is added.
-constexpr uint64 kAddStateProperties =
+inline constexpr uint64_t kAddStateProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor | kIDeterministic |
     kNonIDeterministic | kODeterministic | kNonODeterministic | kEpsilons |
     kNoEpsilons | kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons |
@@ -212,31 +213,31 @@ constexpr uint64 kAddStateProperties =
     kNotCoAccessible | kNotString | kWeightedCycles | kUnweightedCycles;
 
 // Properties that are preserved when an FST arc is added.
-constexpr uint64 kAddArcProperties =
+inline constexpr uint64_t kAddArcProperties =
     kExpanded | kMutable | kError | kNotAcceptor | kNonIDeterministic |
     kNonODeterministic | kEpsilons | kIEpsilons | kOEpsilons |
     kNotILabelSorted | kNotOLabelSorted | kWeighted | kCyclic | kInitialCyclic |
     kNotTopSorted | kAccessible | kCoAccessible | kWeightedCycles;
 
 // Properties that are preserved when an FST arc is set.
-constexpr uint64 kSetArcProperties = kExpanded | kMutable | kError;
+inline constexpr uint64_t kSetArcProperties = kExpanded | kMutable | kError;
 
 // Properties that are preserved when FST states are deleted.
-constexpr uint64 kDeleteStatesProperties =
+inline constexpr uint64_t kDeleteStatesProperties =
     kExpanded | kMutable | kError | kAcceptor | kIDeterministic |
     kODeterministic | kNoEpsilons | kNoIEpsilons | kNoOEpsilons |
     kILabelSorted | kOLabelSorted | kUnweighted | kAcyclic | kInitialAcyclic |
     kTopSorted | kUnweightedCycles;
 
 // Properties that are preserved when FST arcs are deleted.
-constexpr uint64 kDeleteArcsProperties =
+inline constexpr uint64_t kDeleteArcsProperties =
     kExpanded | kMutable | kError | kAcceptor | kIDeterministic |
     kODeterministic | kNoEpsilons | kNoIEpsilons | kNoOEpsilons |
     kILabelSorted | kOLabelSorted | kUnweighted | kAcyclic | kInitialAcyclic |
     kTopSorted | kNotAccessible | kNotCoAccessible | kUnweightedCycles;
 
 // Properties that are preserved when an FST's states are reordered.
-constexpr uint64 kStateSortProperties =
+inline constexpr uint64_t kStateSortProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor | kIDeterministic |
     kNonIDeterministic | kODeterministic | kNonODeterministic | kEpsilons |
     kNoEpsilons | kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons |
@@ -246,7 +247,7 @@ constexpr uint64 kStateSortProperties =
     kNotCoAccessible | kWeightedCycles | kUnweightedCycles;
 
 // Properties that are preserved when an FST's arcs are reordered.
-constexpr uint64 kArcSortProperties =
+inline constexpr uint64_t kArcSortProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor | kIDeterministic |
     kNonIDeterministic | kODeterministic | kNonODeterministic | kEpsilons |
     kNoEpsilons | kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons |
@@ -256,7 +257,7 @@ constexpr uint64 kArcSortProperties =
     kWeightedCycles | kUnweightedCycles;
 
 // Properties that are preserved when an FST's input labels are changed.
-constexpr uint64 kILabelInvariantProperties =
+inline constexpr uint64_t kILabelInvariantProperties =
     kExpanded | kMutable | kError | kODeterministic | kNonODeterministic |
     kOEpsilons | kNoOEpsilons | kOLabelSorted | kNotOLabelSorted | kWeighted |
     kUnweighted | kCyclic | kAcyclic | kInitialCyclic | kInitialAcyclic |
@@ -265,7 +266,7 @@ constexpr uint64 kILabelInvariantProperties =
     kUnweightedCycles;
 
 // Properties that are preserved when an FST's output labels are changed.
-constexpr uint64 kOLabelInvariantProperties =
+inline constexpr uint64_t kOLabelInvariantProperties =
     kExpanded | kMutable | kError | kIDeterministic | kNonIDeterministic |
     kIEpsilons | kNoIEpsilons | kILabelSorted | kNotILabelSorted | kWeighted |
     kUnweighted | kCyclic | kAcyclic | kInitialCyclic | kInitialAcyclic |
@@ -275,7 +276,7 @@ constexpr uint64 kOLabelInvariantProperties =
 
 // Properties that are preserved when an FST's weights are changed. This
 // assumes that the set of states that are non-final is not changed.
-constexpr uint64 kWeightInvariantProperties =
+inline constexpr uint64_t kWeightInvariantProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor | kIDeterministic |
     kNonIDeterministic | kODeterministic | kNonODeterministic | kEpsilons |
     kNoEpsilons | kIEpsilons | kNoIEpsilons | kOEpsilons | kNoOEpsilons |
@@ -286,7 +287,7 @@ constexpr uint64 kWeightInvariantProperties =
 
 // Properties that are preserved when a superfinal state is added and an FST's
 // final weights are directed to it via new transitions.
-constexpr uint64 kAddSuperFinalProperties =
+inline constexpr uint64_t kAddSuperFinalProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor |
     kNonIDeterministic | kNonODeterministic | kEpsilons | kIEpsilons |
     kOEpsilons | kNotILabelSorted | kNotOLabelSorted | kWeighted | kUnweighted |
@@ -296,7 +297,7 @@ constexpr uint64 kAddSuperFinalProperties =
 
 // Properties that are preserved when a superfinal state is removed and the
 // epsilon transitions directed to it are made final weights.
-constexpr uint64 kRmSuperFinalProperties =
+inline constexpr uint64_t kRmSuperFinalProperties =
     kExpanded | kMutable | kError | kAcceptor | kNotAcceptor | kIDeterministic |
     kODeterministic | kNoEpsilons | kNoIEpsilons | kNoOEpsilons |
     kILabelSorted | kOLabelSorted | kWeighted | kUnweighted | kCyclic |
@@ -305,89 +306,93 @@ constexpr uint64 kRmSuperFinalProperties =
     kUnweightedCycles;
 
 // All binary properties.
-constexpr uint64 kBinaryProperties = 0x0000000000000007ULL;
+inline constexpr uint64_t kBinaryProperties = 0x0000000000000007ULL;
 
 // All trinary properties.
-constexpr uint64 kTrinaryProperties = 0x0000ffffffff0000ULL;
+inline constexpr uint64_t kTrinaryProperties = 0x0000ffffffff0000ULL;
 
 // COMPUTED PROPERTIES
 
 // 1st bit of trinary properties.
-constexpr uint64 kPosTrinaryProperties =
+inline constexpr uint64_t kPosTrinaryProperties =
     kTrinaryProperties & 0x5555555555555555ULL;
 
 // 2nd bit of trinary properties.
-constexpr uint64 kNegTrinaryProperties =
+inline constexpr uint64_t kNegTrinaryProperties =
     kTrinaryProperties & 0xaaaaaaaaaaaaaaaaULL;
 
 // All properties.
-constexpr uint64 kFstProperties = kBinaryProperties | kTrinaryProperties;
+inline constexpr uint64_t kFstProperties =
+    kBinaryProperties | kTrinaryProperties;
 
 // PROPERTY FUNCTIONS and STRING NAMES (defined in properties.cc).
 
 // Below are functions for getting property bit vectors when executing
 // mutation operations.
-inline uint64 SetStartProperties(uint64 inprops);
+inline uint64_t SetStartProperties(uint64_t inprops);
 
 template <typename Weight>
-uint64 SetFinalProperties(uint64 inprops, const Weight &old_weight,
-                          const Weight &new_weight);
+uint64_t SetFinalProperties(uint64_t inprops, const Weight &old_weight,
+                            const Weight &new_weight);
 
-inline uint64 AddStateProperties(uint64 inprops);
+inline uint64_t AddStateProperties(uint64_t inprops);
 
 template <typename A>
-uint64 AddArcProperties(uint64 inprops, typename A::StateId s, const A &arc,
-                        const A *prev_arc);
+uint64_t AddArcProperties(uint64_t inprops, typename A::StateId s, const A &arc,
+                          const A *prev_arc);
 
-inline uint64 DeleteStatesProperties(uint64 inprops);
+inline uint64_t DeleteStatesProperties(uint64_t inprops);
 
-inline uint64 DeleteAllStatesProperties(uint64 inprops, uint64 staticProps);
+inline uint64_t DeleteAllStatesProperties(uint64_t inprops,
+                                          uint64_t staticProps);
 
-inline uint64 DeleteArcsProperties(uint64 inprops);
+inline uint64_t DeleteArcsProperties(uint64_t inprops);
 
-uint64 ClosureProperties(uint64 inprops, bool star, bool delayed = false);
+uint64_t ClosureProperties(uint64_t inprops, bool star, bool delayed = false);
 
-uint64 ComplementProperties(uint64 inprops);
+uint64_t ComplementProperties(uint64_t inprops);
 
-uint64 ComposeProperties(uint64 inprops1, uint64 inprops2);
+uint64_t ComposeProperties(uint64_t inprops1, uint64_t inprops2);
 
-uint64 ConcatProperties(uint64 inprops1, uint64 inprops2, bool delayed = false);
+uint64_t ConcatProperties(uint64_t inprops1, uint64_t inprops2,
+                          bool delayed = false);
 
-uint64 DeterminizeProperties(uint64 inprops, bool has_subsequential_label,
-                             bool distinct_psubsequential_labels);
+uint64_t DeterminizeProperties(uint64_t inprops, bool has_subsequential_label,
+                               bool distinct_psubsequential_labels);
 
-uint64 FactorWeightProperties(uint64 inprops);
+uint64_t FactorWeightProperties(uint64_t inprops);
 
-uint64 InvertProperties(uint64 inprops);
+uint64_t InvertProperties(uint64_t inprops);
 
-uint64 ProjectProperties(uint64 inprops, bool project_input);
+uint64_t ProjectProperties(uint64_t inprops, bool project_input);
 
-uint64 RandGenProperties(uint64 inprops, bool weighted);
+uint64_t RandGenProperties(uint64_t inprops, bool weighted);
 
-uint64 RelabelProperties(uint64 inprops);
+uint64_t RelabelProperties(uint64_t inprops);
 
-uint64 ReplaceProperties(const std::vector<uint64> &inprops, size_t root,
-                         bool epsilon_on_call, bool epsilon_on_return,
-                         bool out_epsilon_on_call, bool out_epsilon_on_return,
-                         bool replace_transducer, bool no_empty_fst,
-                         bool all_ilabel_sorted, bool all_olabel_sorted,
-                         bool all_negative_or_dense);
+uint64_t ReplaceProperties(const std::vector<uint64_t> &inprops, size_t root,
+                           bool epsilon_on_call, bool epsilon_on_return,
+                           bool out_epsilon_on_call, bool out_epsilon_on_return,
+                           bool replace_transducer, bool no_empty_fst,
+                           bool all_ilabel_sorted, bool all_olabel_sorted,
+                           bool all_negative_or_dense);
 
-uint64 ReverseProperties(uint64 inprops, bool has_superinitial);
+uint64_t ReverseProperties(uint64_t inprops, bool has_superinitial);
 
-uint64 ReweightProperties(uint64 inprops, bool added_start_epsilon);
+uint64_t ReweightProperties(uint64_t inprops, bool added_start_epsilon);
 
-uint64 RmEpsilonProperties(uint64 inprops, bool delayed = false);
+uint64_t RmEpsilonProperties(uint64_t inprops, bool delayed = false);
 
-uint64 ShortestPathProperties(uint64 props, bool tree = false);
+uint64_t ShortestPathProperties(uint64_t props, bool tree = false);
 
-uint64 SynchronizeProperties(uint64 inprops);
+uint64_t SynchronizeProperties(uint64_t inprops);
 
-uint64 UnionProperties(uint64 inprops1, uint64 inprops2, bool delayed = false);
+uint64_t UnionProperties(uint64_t inprops1, uint64_t inprops2,
+                         bool delayed = false);
 
 // Definitions of inlined functions.
 
-uint64 SetStartProperties(uint64 inprops) {
+uint64_t SetStartProperties(uint64_t inprops) {
   auto outprops = inprops & kSetStartProperties;
   if (inprops & kAcyclic) {
     outprops |= kInitialAcyclic;
@@ -395,28 +400,28 @@ uint64 SetStartProperties(uint64 inprops) {
   return outprops;
 }
 
-uint64 AddStateProperties(uint64 inprops) {
+uint64_t AddStateProperties(uint64_t inprops) {
   return inprops & kAddStateProperties;
 }
 
-uint64 DeleteStatesProperties(uint64 inprops) {
+uint64_t DeleteStatesProperties(uint64_t inprops) {
   return inprops & kDeleteStatesProperties;
 }
 
-uint64 DeleteAllStatesProperties(uint64 inprops, uint64 staticprops) {
+uint64_t DeleteAllStatesProperties(uint64_t inprops, uint64_t staticprops) {
   const auto outprops = inprops & kError;
   return outprops | kNullProperties | staticprops;
 }
 
-uint64 DeleteArcsProperties(uint64 inprops) {
+uint64_t DeleteArcsProperties(uint64_t inprops) {
   return inprops & kDeleteArcsProperties;
 }
 
 // Definitions of template functions.
 
 template <typename Weight>
-uint64 SetFinalProperties(uint64 inprops, const Weight &old_weight,
-                          const Weight &new_weight) {
+uint64_t SetFinalProperties(uint64_t inprops, const Weight &old_weight,
+                            const Weight &new_weight) {
   auto outprops = inprops;
   if (old_weight != Weight::Zero() && old_weight != Weight::One()) {
     outprops &= ~kWeighted;
@@ -437,8 +442,8 @@ uint64 SetFinalProperties(uint64 inprops, const Weight &old_weight,
 /// \param prev_arc the previously-added (or "last") arc of state s, or nullptr
 //                  if s currently has no arcs.
 template <typename Arc>
-uint64 AddArcProperties(uint64 inprops, typename Arc::StateId s, const Arc &arc,
-                        const Arc *prev_arc) {
+uint64_t AddArcProperties(uint64_t inprops, typename Arc::StateId s,
+                          const Arc &arc, const Arc *prev_arc) {
   using Weight = typename Arc::Weight;
   auto outprops = inprops;
   if (arc.ilabel != arc.olabel) {
@@ -484,30 +489,31 @@ uint64 AddArcProperties(uint64 inprops, typename Arc::StateId s, const Arc &arc,
   return outprops;
 }
 
-extern const char *PropertyNames[];
-
 namespace internal {
 
+extern const std::string_view PropertyNames[];
+
 // For a binary property, the bit is always returned set. For a trinary (i.e.,
 // two-bit) property, both bits are returned set iff either corresponding input
 // bit is set.
-inline uint64 KnownProperties(uint64 props) {
+inline uint64_t KnownProperties(uint64_t props) {
   return kBinaryProperties | (props & kTrinaryProperties) |
          ((props & kPosTrinaryProperties) << 1) |
          ((props & kNegTrinaryProperties) >> 1);
 }
 
 // Tests compatibility between two sets of properties.
-inline bool CompatProperties(uint64 props1, uint64 props2) {
+inline bool CompatProperties(uint64_t props1, uint64_t props2) {
   const auto known_props1 = KnownProperties(props1);
   const auto known_props2 = KnownProperties(props2);
   const auto known_props = known_props1 & known_props2;
   const auto incompat_props = (props1 & known_props) ^ (props2 & known_props);
   if (incompat_props) {
-    uint64 prop = 1;
+    uint64_t prop = 1;
     for (int i = 0; i < 64; ++i, prop <<= 1) {
       if (prop & incompat_props) {
-        LOG(ERROR) << "CompatProperties: Mismatch: " << PropertyNames[i]
+        LOG(ERROR) << "CompatProperties: Mismatch: "
+                   << internal::PropertyNames[i]
                    << ": props1 = " << (props1 & prop ? "true" : "false")
                    << ", props2 = " << (props2 & prop ? "true" : "false");
       }
