@@ -21,9 +21,9 @@
 #ifndef FST_RANDEQUIVALENT_H_
 #define FST_RANDEQUIVALENT_H_
 
+#include <cstdint>
 #include <random>
 
-#include <fst/types.h>
 #include <fst/log.h>
 
 #include <fst/arcsort.h>
@@ -32,6 +32,7 @@
 #include <fst/randgen.h>
 #include <fst/shortest-distance.h>
 #include <fst/vector-fst.h>
+#include <fst/weight.h>
 
 
 namespace fst {
@@ -45,9 +46,10 @@ namespace fst {
 // generated path and checks that these two values are within a user-specified
 // delta. Returns optional error value (when FST_FLAGS_error_fatal = false).
 template <class Arc, class ArcSelector>
-bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32 npath,
+bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32_t npath,
                     const RandGenOptions<ArcSelector> &opts,
-                    float delta = kDelta, uint64 seed = std::random_device()(),
+                    float delta = kDelta,
+                    uint64_t seed = std::random_device()(),
                     bool *error = nullptr) {
   using Weight = typename Arc::Weight;
   if (error) *error = false;
@@ -71,7 +73,7 @@ bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32 npath,
   bool result = true;
   std::mt19937 rand(seed);
   std::bernoulli_distribution coin(.5);
-  for (int32 n = 0; n < npath; ++n) {
+  for (int32_t n = 0; n < npath; ++n) {
     VectorFst<Arc> path;
     const auto &fst = coin(rand) ? sfst1 : sfst2;
     RandGen(fst, &path, opts);
@@ -84,8 +86,7 @@ bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32 npath,
     ArcSort(&cfst1, ocomp);
     Compose(cfst1, opath, &pfst1);
     // Gives up if there are epsilon cycles in a non-idempotent semiring.
-    if (!(Weight::Properties() & kIdempotent) &&
-        pfst1.Properties(kCyclic, true)) {
+    if (!IsIdempotent<Weight>::value && pfst1.Properties(kCyclic, true)) {
       continue;
     }
     const auto sum1 = ShortestDistance(pfst1);
@@ -95,8 +96,7 @@ bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32 npath,
     VectorFst<Arc> pfst2;
     Compose(cfst2, opath, &pfst2);
     // Gives up if there are epsilon cycles in a non-idempotent semiring.
-    if (!(Weight::Properties() & kIdempotent) &&
-        pfst2.Properties(kCyclic, true)) {
+    if (!IsIdempotent<Weight>::value && pfst2.Properties(kCyclic, true)) {
       continue;
     }
     const auto sum2 = ShortestDistance(pfst2);
@@ -118,9 +118,10 @@ bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32 npath,
 // (no longer than the path_length) using a user-specified seed, optionally
 // indicating an error setting an optional error argument to true.
 template <class Arc>
-bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32 npath,
-                    float delta = kDelta, uint64 seed = std::random_device()(),
-                    int32 max_length = std::numeric_limits<int32>::max(),
+bool RandEquivalent(const Fst<Arc> &fst1, const Fst<Arc> &fst2, int32_t npath,
+                    float delta = kDelta,
+                    uint64_t seed = std::random_device()(),
+                    int32_t max_length = std::numeric_limits<int32_t>::max(),
                     bool *error = nullptr) {
   const UniformArcSelector<Arc> uniform_selector(seed);
   const RandGenOptions<UniformArcSelector<Arc>> opts(uniform_selector,
