@@ -20,12 +20,12 @@
 #ifndef FST_REPLACE_H_
 #define FST_REPLACE_H_
 
+#include <cstdint>
 #include <set>
 #include <string>
 #include <utility>
 #include <vector>
 
-#include <fst/types.h>
 #include <fst/log.h>
 
 #include <fst/cache.h>
@@ -111,23 +111,23 @@ class ReplaceRootSelector {
 template <class StateId, class PrefixId>
 class ReplaceFingerprint {
  public:
-  explicit ReplaceFingerprint(const std::vector<uint64> *size_array)
+  explicit ReplaceFingerprint(const std::vector<uint64_t> *size_array)
       : size_array_(size_array) {}
 
-  uint64 operator()(const ReplaceStateTuple<StateId, PrefixId> &tuple) const {
+  uint64_t operator()(const ReplaceStateTuple<StateId, PrefixId> &tuple) const {
     return tuple.prefix_id * size_array_->back() +
            size_array_->at(tuple.fst_id - 1) + tuple.fst_state;
   }
 
  private:
-  const std::vector<uint64> *size_array_;
+  const std::vector<uint64_t> *size_array_;
 };
 
 // Useful when the fst_state uniquely define the tuple.
 template <class StateId, class PrefixId>
 class ReplaceFstStateFingerprint {
  public:
-  uint64 operator()(const ReplaceStateTuple<StateId, PrefixId> &tuple) const {
+  uint64_t operator()(const ReplaceStateTuple<StateId, PrefixId> &tuple) const {
     return tuple.fst_state;
   }
 };
@@ -137,9 +137,30 @@ template <typename S, typename P>
 class ReplaceHash {
  public:
   size_t operator()(const ReplaceStateTuple<S, P> &t) const {
+    // TODO(189578616): Use the AbslHashValue framework.  See
+    // b/189578616#comment8 for a proposed patch and a discussion of the
+    // concerns for making such a change.
+    //
+    // We want three prime numbers that are all reasonably large and whose
+    // differences are far from each other.  (E.g., we want prime1-prime0 to be
+    // far from prime2-prime1).  It would be safer still to use large prime
+    // numbers (i.e., prime numbers that use all 64 bits on a 64-bit machine and
+    // all 32-bits on a 32-bit machine), so that all 64-bits (respectively
+    // 32-bits) of the resulting hash would look random.  However, these
+    // modest-sized prime numbers are good enough for hash tables (such as
+    // std::unordered_set and std::unordered_set) that use the low-order bits
+    // of the hash.
+    //
+    // It is important that all three components are multiplied by a prime
+    // number.  E.g., don't compute
+    //   t.prefix_id + t.fst_id * prime1 + t.fst_state * prime2
+    // which is just the identity on t.prefix_id.  Using the identity will
+    // result in long probe sequences in open-addressed hash tables (such as
+    // std::unordered_map).
     static constexpr size_t prime0 = 7853;
-    static constexpr size_t prime1 = 7867;
-    return t.prefix_id + t.fst_id * prime0 + t.fst_state * prime1;
+    static constexpr size_t prime1 = 9001;
+    static constexpr size_t prime2 = 100003;
+    return t.prefix_id * prime0 + t.fst_id * prime1 + t.fst_state * prime2;
   }
 };
 
@@ -230,20 +251,20 @@ class VectorHashReplaceStateTable {
       Label root)
       : root_size_(0) {
     size_array_.push_back(0);
-    for (const auto &fst_pair : fst_list) {
-      if (fst_pair.first == root) {
-        root_size_ = CountStates(*(fst_pair.second));
+    for (const auto &[label, fst] : fst_list) {
+      if (label == root) {
+        root_size_ = CountStates(*fst);
         size_array_.push_back(size_array_.back());
       } else {
         size_array_.push_back(size_array_.back() +
-                              CountStates(*(fst_pair.second)));
+                              CountStates(*fst));
       }
     }
-    state_table_.reset(
-        new StateTable(ReplaceRootSelector<StateId, PrefixId>(),
-                       ReplaceFstStateFingerprint<StateId, PrefixId>(),
-                       ReplaceFingerprint<StateId, PrefixId>(&size_array_),
-                       root_size_, root_size_ + size_array_.back()));
+    state_table_ = std::make_unique<StateTable>(
+        ReplaceRootSelector<StateId, PrefixId>(),
+        ReplaceFstStateFingerprint<StateId, PrefixId>(),
+        ReplaceFingerprint<StateId, PrefixId>(&size_array_), root_size_,
+        root_size_ + size_array_.back());
   }
 
   VectorHashReplaceStateTable(
@@ -251,11 +272,11 @@ class VectorHashReplaceStateTable {
       : root_size_(table.root_size_),
         size_array_(table.size_array_),
         prefix_table_(table.prefix_table_) {
-    state_table_.reset(
-        new StateTable(ReplaceRootSelector<StateId, PrefixId>(),
-                       ReplaceFstStateFingerprint<StateId, PrefixId>(),
-                       ReplaceFingerprint<StateId, PrefixId>(&size_array_),
-                       root_size_, root_size_ + size_array_.back()));
+    state_table_ = std::make_unique<StateTable>(
+        ReplaceRootSelector<StateId, PrefixId>(),
+        ReplaceFstStateFingerprint<StateId, PrefixId>(),
+        ReplaceFingerprint<StateId, PrefixId>(&size_array_), root_size_,
+        root_size_ + size_array_.back());
   }
 
   StateId FindState(const StateTuple &tuple) {
@@ -274,7 +295,7 @@ class VectorHashReplaceStateTable {
 
  private:
   StateId root_size_;
-  std::vector<uint64> size_array_;
+  std::vector<uint64_t> size_array_;
   std::unique_ptr<StateTable> state_table_;
   StackPrefixTable prefix_table_;
 };
@@ -381,7 +402,7 @@ struct ReplaceFstOptions : CacheImplOptions<CacheStore> {
   ReplaceFstOptions() : root(kNoLabel) {}
 
   // For backwards compatibility.
-  ReplaceFstOptions(int64 root, bool epsilon_replace_arc)
+  ReplaceFstOptions(int64_t root, bool epsilon_replace_arc)
       : root(root),
         call_label_type(epsilon_replace_arc ? REPLACE_LABEL_NEITHER
                                             : REPLACE_LABEL_INPUT),
@@ -421,14 +442,14 @@ bool ReplaceTransducer(ReplaceLabelType call_label_type,
 }
 
 template <class Arc>
-uint64 ReplaceFstProperties(typename Arc::Label root_label,
-                            const FstList<Arc> &fst_list,
-                            ReplaceLabelType call_label_type,
-                            ReplaceLabelType return_label_type,
-                            typename Arc::Label call_output_label,
-                            bool *sorted_and_non_empty) {
+uint64_t ReplaceFstProperties(typename Arc::Label root_label,
+                              const FstList<Arc> &fst_list,
+                              ReplaceLabelType call_label_type,
+                              ReplaceLabelType return_label_type,
+                              typename Arc::Label call_output_label,
+                              bool *sorted_and_non_empty) {
   using Label = typename Arc::Label;
-  std::vector<uint64> inprops;
+  std::vector<uint64_t> inprops;
   bool all_ilabel_sorted = true;
   bool all_olabel_sorted = true;
   bool all_non_empty = true;
@@ -717,10 +738,10 @@ class ReplaceFstImpl
     }
   }
 
-  uint64 Properties() const override { return Properties(kFstProperties); }
+  uint64_t Properties() const override { return Properties(kFstProperties); }
 
   // Sets error if found, and returns other FST impl properties.
-  uint64 Properties(uint64 mask) const override {
+  uint64_t Properties(uint64_t mask) const override {
     if (mask & kError) {
       for (Label i = 1; i < fst_array_.size(); ++i) {
         if (fst_array_[i]->Properties(kError, false)) {
@@ -779,7 +800,7 @@ class ReplaceFstImpl
   // If acpp is null, only returns true if a final arcp is required, but does
   // not actually compute it.
   bool ComputeFinalArc(const StateTuple &tuple, Arc *arcp,
-                       uint8 flags = kArcValueFlags) {
+                       uint8_t flags = kArcValueFlags) {
     const auto fst_state = tuple.fst_state;
     if (fst_state == kNoStateId) return false;
     // If state is final, pops the stack.
@@ -810,7 +831,7 @@ class ReplaceFstImpl
   // Returns false if the underlying arc corresponds to no arc in the resulting
   // FST.
   bool ComputeArc(const StateTuple &tuple, const Arc &arc, Arc *arcp,
-                  uint8 flags = kArcValueFlags) {
+                  uint8_t flags = kArcValueFlags) {
     if (!EpsilonOnInput(call_label_type_) &&
         (flags == (flags & (kArcILabelValue | kArcWeightValue)))) {
       *arcp = arc;
@@ -864,8 +885,8 @@ class ReplaceFstImpl
   }
 
   // Returns the arc iterator flags supported by this FST.
-  uint8 ArcIteratorFlags() const {
-    uint8 flags = kArcValueFlags;
+  uint8_t ArcIteratorFlags() const {
+    uint8_t flags = kArcValueFlags;
     if (!always_cache_) flags |= kArcNoCache;
     return flags;
   }
@@ -909,8 +930,8 @@ class ReplaceFstImpl
   // Runtime options
   ReplaceLabelType call_label_type_;    // How to label call arc.
   ReplaceLabelType return_label_type_;  // How to label return arc.
-  int64 call_output_label_;  // Specifies output label to put on call arc
-  int64 return_label_;       // Specifies label to put on return arc.
+  int64_t call_output_label_;  // Specifies output label to put on call arc
+  int64_t return_label_;       // Specifies label to put on return arc.
   bool always_cache_;        // Disable optional caching of arc iterator?
 
   // State table.
@@ -1207,9 +1228,9 @@ class ArcIterator<ReplaceFst<Arc, StateTable, CacheStore>> {
 
   void Seek(size_t pos) { pos_ = pos; }
 
-  uint8 Flags() const { return flags_; }
+  uint8_t Flags() const { return flags_; }
 
-  void SetFlags(uint8 flags, uint8 mask) {
+  void SetFlags(uint8_t flags, uint8_t mask) {
     // Updates the flags taking into account what flags are supported
     // by the FST.
     flags_ &= ~mask;
@@ -1233,16 +1254,16 @@ class ArcIterator<ReplaceFst<Arc, StateTable, CacheStore>> {
   ssize_t pos_;             // Current position.
   mutable ssize_t offset_;  // Offset between position in iterator and in arcs_.
   ssize_t num_arcs_;        // Number of arcs at state_.
-  uint8 flags_;             // Behavorial flags for the arc iterator
+  uint8_t flags_;           // Behavorial flags for the arc iterator
   mutable Arc arc_;         // Memory to temporarily store computed arcs.
 
   mutable ArcIteratorData<Arc> cache_data_;  // Arc iterator data in cache.
   mutable ArcIteratorData<Arc> local_data_;  // Arc iterator data in local FST.
 
   mutable const Arc *arcs_;    // Array of arcs.
-  mutable uint8 data_flags_;   // Arc value flags valid for data in arcs_.
+  mutable uint8_t data_flags_;  // Arc value flags valid for data in arcs_.
   mutable Arc final_arc_;      // Final arc (when required).
-  mutable uint8 final_flags_;  // Arc value flags valid for final_arc_.
+  mutable uint8_t final_flags_;  // Arc value flags valid for final_arc_.
 
   ArcIterator(const ArcIterator &) = delete;
   ArcIterator &operator=(const ArcIterator &) = delete;
@@ -1318,8 +1339,8 @@ class ReplaceFstMatcher : public MatcherBase<Arc> {
     matcher_.resize(fst_array.size());
     for (Label i = 0; i < fst_array.size(); ++i) {
       if (fst_array[i]) {
-        matcher_[i].reset(
-            new LocalMatcher(*fst_array[i], match_type_, kMultiEpsList));
+        matcher_[i] = std::make_unique<LocalMatcher>(
+            *fst_array[i], match_type_, kMultiEpsList);
         auto it = impl_->nonterminal_set_.begin();
         for (; it != impl_->nonterminal_set_.end(); ++it) {
           matcher_[i]->AddMultiEpsLabel(*it);
@@ -1350,7 +1371,7 @@ class ReplaceFstMatcher : public MatcherBase<Arc> {
 
   const Fst<Arc> &GetFst() const override { return fst_; }
 
-  uint64 Properties(uint64 props) const override { return props; }
+  uint64_t Properties(uint64_t props) const override { return props; }
 
   // Sets the state from which our matching happens.
   void SetState(StateId s) final {
