@@ -21,9 +21,9 @@
 #define FST_REVERSE_H_
 
 #include <algorithm>
+#include <cstdint>
 #include <vector>
 
-#include <fst/types.h>
 
 #include <fst/cache.h>
 
@@ -58,8 +58,8 @@ void Reverse(const Fst<FromArc> &ifst, MutableFst<ToArc> *ofst,
   StateId istart = ifst.Start();
   StateId ostart = kNoStateId;
   StateId offset = 0;
-  uint64 dfs_iprops = 0;
-  uint64 dfs_oprops = 0;
+  uint64_t dfs_iprops = 0;
+  uint64_t dfs_oprops = 0;
   if (!require_superinitial) {
     for (StateIterator<Fst<FromArc>> siter(ifst); !siter.Done(); siter.Next()) {
       const auto s = siter.Value();
