@@ -26,11 +26,11 @@
 namespace fst {
 namespace script {
 
-using ComposeArgs = std::tuple<const FstClass &, const FstClass &,
-                               MutableFstClass *, const ComposeOptions &>;
+using FstComposeArgs = std::tuple<const FstClass &, const FstClass &,
+                                  MutableFstClass *, const ComposeOptions &>;
 
 template <class Arc>
-void Compose(ComposeArgs *args) {
+void Compose(FstComposeArgs *args) {
   const Fst<Arc> &ifst1 = *std::get<0>(*args).GetFst<Arc>();
   const Fst<Arc> &ifst2 = *std::get<1>(*args).GetFst<Arc>();
   MutableFst<Arc> *ofst = std::get<2>(*args)->GetMutableFst<Arc>();
