@@ -28,10 +28,10 @@
 namespace fst {
 namespace script {
 
-using EncodeArgs = std::tuple<MutableFstClass *, EncodeMapperClass *>;
+using FstEncodeArgs = std::tuple<MutableFstClass *, EncodeMapperClass *>;
 
 template <class Arc>
-void Encode(EncodeArgs *args) {
+void Encode(FstEncodeArgs *args) {
   MutableFst<Arc> *fst = std::get<0>(*args)->GetMutableFst<Arc>();
   EncodeMapper<Arc> *mapper = std::get<1>(*args)->GetEncodeMapper<Arc>();
   Encode(fst, mapper);
