@@ -18,15 +18,17 @@
 #ifndef FST_SCRIPT_ENCODEMAPPER_CLASS_H_
 #define FST_SCRIPT_ENCODEMAPPER_CLASS_H_
 
+#include <cstdint>
 #include <iostream>
 #include <memory>
 #include <string>
+#include <utility>
 
-#include <fst/types.h>
 #include <fst/encode.h>
 #include <fst/generic-register.h>
 #include <fst/script/arc-class.h>
 #include <fst/script/fst-class.h>
+#include <string_view>
 
 // Scripting API support for EncodeMapper.
 
@@ -41,8 +43,8 @@ class EncodeMapperImplBase {
   virtual const std::string &ArcType() const = 0;
   virtual const std::string &WeightType() const = 0;
   virtual EncodeMapperImplBase *Copy() const = 0;
-  virtual uint8 Flags() const = 0;
-  virtual uint64 Properties(uint64) = 0;
+  virtual uint8_t Flags() const = 0;
+  virtual uint64_t Properties(uint64_t) = 0;
   virtual EncodeType Type() const = 0;
   virtual bool Write(const std::string &) const = 0;
   virtual bool Write(std::ostream &, const std::string &) const = 0;
@@ -70,9 +72,9 @@ class EncodeMapperClassImpl : public EncodeMapperImplBase {
     return new EncodeMapperClassImpl<Arc>(mapper_);
   }
 
-  uint8 Flags() const final { return mapper_.Flags(); }
+  uint8_t Flags() const final { return mapper_.Flags(); }
 
-  uint64 Properties(uint64 inprops) final {
+  uint64_t Properties(uint64_t inprops) final {
     return mapper_.Properties(inprops);
   }
 
@@ -123,12 +125,12 @@ class EncodeMapperClass {
  public:
   EncodeMapperClass() : impl_(nullptr) {}
 
-  EncodeMapperClass(const std::string &arc_type, uint8 flags,
+  EncodeMapperClass(std::string_view arc_type, uint8_t flags,
                     EncodeType type = ENCODE);
 
   template <class Arc>
   explicit EncodeMapperClass(const EncodeMapper<Arc> &mapper)
-      : impl_(new EncodeMapperClassImpl<Arc>(mapper)) {}
+      : impl_(std::make_unique<EncodeMapperClassImpl<Arc>>(mapper)) {}
 
   EncodeMapperClass(const EncodeMapperClass &other)
       : impl_(other.impl_ == nullptr ? nullptr : other.impl_->Copy()) {}
@@ -144,15 +146,16 @@ class EncodeMapperClass {
 
   const std::string &WeightType() const { return impl_->WeightType(); }
 
-  uint8 Flags() const { return impl_->Flags(); }
+  uint8_t Flags() const { return impl_->Flags(); }
 
-  uint64 Properties(uint64 inprops) { return impl_->Properties(inprops); }
+  uint64_t Properties(uint64_t inprops) { return impl_->Properties(inprops); }
 
   EncodeType Type() const { return impl_->Type(); }
 
-  static EncodeMapperClass *Read(const std::string &source);
+  static std::unique_ptr<EncodeMapperClass> Read(const std::string &source);
 
-  static EncodeMapperClass *Read(std::istream &strm, const std::string &source);
+  static std::unique_ptr<EncodeMapperClass> Read(std::istream &strm,
+                                                 const std::string &source);
 
   bool Write(const std::string &source) const { return impl_->Write(source); }
 
@@ -179,7 +182,7 @@ class EncodeMapperClass {
     if (Arc::Type() != ArcType()) {
       return nullptr;
     } else {
-      auto *typed_impl = fst::down_cast<EncodeMapperClassImpl<Arc> *>(impl_.get());
+      auto *typed_impl = down_cast<EncodeMapperClassImpl<Arc> *>(impl_.get());
       return typed_impl->GetImpl();
     }
   }
@@ -189,7 +192,7 @@ class EncodeMapperClass {
     if (Arc::Type() != ArcType()) {
       return nullptr;
     } else {
-      auto *typed_impl = fst::down_cast<EncodeMapperClassImpl<Arc> *>(impl_.get());
+      auto *typed_impl = down_cast<EncodeMapperClassImpl<Arc> *>(impl_.get());
       return typed_impl->GetImpl();
     }
   }
@@ -197,20 +200,23 @@ class EncodeMapperClass {
   // Required for registration.
 
   template <class Arc>
-  static EncodeMapperClass *Read(std::istream &strm,
-                                 const std::string &source) {
+  static std::unique_ptr<EncodeMapperClass> Read(std::istream &strm,
+                                                 const std::string &source) {
     std::unique_ptr<EncodeMapper<Arc>> mapper(
         EncodeMapper<Arc>::Read(strm, source));
-    return mapper ? new EncodeMapperClass(*mapper) : nullptr;
+    return mapper ? std::make_unique<EncodeMapperClass>(*mapper) : nullptr;
   }
 
   template <class Arc>
-  static EncodeMapperImplBase *Create(uint8 flags, EncodeType type = ENCODE) {
-    return new EncodeMapperClassImpl<Arc>(EncodeMapper<Arc>(flags, type));
+  static std::unique_ptr<EncodeMapperImplBase> Create(
+      uint8_t flags, EncodeType type = ENCODE) {
+    return std::make_unique<EncodeMapperClassImpl<Arc>>(
+        EncodeMapper<Arc>(flags, type));
   }
 
  private:
-  explicit EncodeMapperClass(EncodeMapperImplBase *impl) : impl_(impl) {}
+  explicit EncodeMapperClass(std::unique_ptr<EncodeMapperImplBase> impl)
+      : impl_(std::move(impl)) {}
 
   const EncodeMapperImplBase *GetImpl() const { return impl_.get(); }
 
@@ -241,28 +247,30 @@ class EncodeMapperClassIORegister
                              EncodeMapperClassRegEntry<Reader, Creator>,
                              EncodeMapperClassIORegister<Reader, Creator>> {
  public:
-  Reader GetReader(const std::string &arc_type) const {
+  Reader GetReader(std::string_view arc_type) const {
     return this->GetEntry(arc_type).reader;
   }
 
-  Creator GetCreator(const std::string &arc_type) const {
+  Creator GetCreator(std::string_view arc_type) const {
     return this->GetEntry(arc_type).creator;
   }
 
  protected:
-  std::string ConvertKeyToSoFilename(const std::string &key) const final {
+  std::string ConvertKeyToSoFilename(std::string_view key) const final {
     std::string legal_type(key);
     ConvertToLegalCSymbol(&legal_type);
-    return legal_type + "-arc.so";
+    legal_type.append("-arc.so");
+    return legal_type;
   }
 };
 
 // Struct containing everything needed to register a particular type
 struct EncodeMapperClassIORegistration {
-  using Reader = EncodeMapperClass *(*)(std::istream &stream,
-                                        const std::string &source);
+  using Reader = std::unique_ptr<EncodeMapperClass> (*)(
+      std::istream &stream, const std::string &source);
 
-  using Creator = EncodeMapperImplBase *(*)(uint8 flags, EncodeType type);
+  using Creator = std::unique_ptr<EncodeMapperImplBase> (*)(uint8_t flags,
+                                                            EncodeType type);
 
   using Entry = EncodeMapperClassRegEntry<Reader, Creator>;
 
