@@ -1,20 +1,21 @@
-
-// Licensed under the Apache License, Version 2.0 (the "License");
+// Copyright 2005-2020 Google LLC
+//
+// Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
 //
 //     http://www.apache.org/licenses/LICENSE-2.0
 //
 // Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
+// distributed under the License is distributed on an 'AS IS' BASIS,
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
 //
-// Copyright 2005-2010 Google, Inc.
-// Author: jpr@google.com (Jake Ratkiewicz)
-
-// Forward declarations for the FST and FST-script classes.
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
+//
+// Forward declarations for the FST and FST script classes.
 
 #ifndef FST_SCRIPT_FSTSCRIPT_DECL_H_
 #define FST_SCRIPT_FSTSCRIPT_DECL_H_
@@ -24,12 +25,22 @@
 namespace fst {
 namespace script {
 
+class ArcClass;
+
+class ArcIteratorClass;
+class MutableArcIteratorClass;
+
+class EncodeMapperClass;
+
 class FstClass;
 class MutableFstClass;
 class VectorFstClass;
+
+class StateIteratorClass;
+
 class WeightClass;
 
 }  // namespace script
-}  // namespace fst;
+}  // namespace fst
 
 #endif  // FST_SCRIPT_FSTSCRIPT_DECL_H_
