@@ -26,10 +26,10 @@
 namespace fst {
 namespace script {
 
-using ReverseArgs = std::tuple<const FstClass &, MutableFstClass *, bool>;
+using FstReverseArgs = std::tuple<const FstClass &, MutableFstClass *, bool>;
 
 template <class Arc>
-void Reverse(ReverseArgs *args) {
+void Reverse(FstReverseArgs *args) {
   const Fst<Arc> &ifst = *std::get<0>(*args).GetFst<Arc>();
   MutableFst<Arc> *ofst = std::get<1>(*args)->GetMutableFst<Arc>();
   Reverse(ifst, ofst, std::get<2>(*args));
