@@ -26,10 +26,10 @@
 namespace fst {
 namespace script {
 
-using SynchronizeArgs = std::pair<const FstClass &, MutableFstClass *>;
+using FstSynchronizeArgs = std::pair<const FstClass &, MutableFstClass *>;
 
 template <class Arc>
-void Synchronize(SynchronizeArgs *args) {
+void Synchronize(FstSynchronizeArgs *args) {
   const Fst<Arc> &ifst = *std::get<0>(*args).GetFst<Arc>();
   MutableFst<Arc> *ofst = std::get<1>(*args)->GetMutableFst<Arc>();
   Synchronize(ifst, ofst);
