@@ -20,6 +20,7 @@
 #ifndef FST_SHORTEST_PATH_H_
 #define FST_SHORTEST_PATH_H_
 
+#include <cstdint>
 #include <functional>
 #include <type_traits>
 #include <utility>
@@ -42,7 +43,7 @@ struct ShortestPathOptions
   using StateId = typename Arc::StateId;
   using Weight = typename Arc::Weight;
 
-  int32 nshortest;    // Returns n-shortest paths.
+  int32_t nshortest;  // Returns n-shortest paths.
   bool unique;        // Only returns paths with distinct input strings.
   bool has_distance;  // Distance vector already contains the
                       // shortest distance from the initial state.
@@ -57,7 +58,7 @@ struct ShortestPathOptions
   Weight weight_threshold;  // Pruning weight threshold.
   StateId state_threshold;  // Pruning state threshold.
 
-  ShortestPathOptions(Queue *queue, ArcFilter filter, int32 nshortest = 1,
+  ShortestPathOptions(Queue *queue, ArcFilter filter, int32_t nshortest = 1,
                       bool unique = false, bool has_distance = false,
                       float delta = kShortestDelta, bool first_path = false,
                       Weight weight_threshold = Weight::Zero(),
@@ -74,7 +75,7 @@ struct ShortestPathOptions
 
 namespace internal {
 
-constexpr size_t kNoArc = -1;
+inline constexpr size_t kNoArc = -1;
 
 // Helper function for SingleShortestPath building the shortest path as a left-
 // to-right machine backwards from the best final state. It takes the input
@@ -113,36 +114,6 @@ void SingleShortestPathBacktrace(
       kFstProperties);
 }
 
-// Helper function for SingleShortestPath building a tree of shortest paths to
-// every final state in the input FST. It takes the input FST and parent values
-// computed by SingleShortestPath and builds into the output mutable FST the
-// subtree of ifst that consists only of the best paths to all final states.
-// This is not normally called by users; see ShortestPath instead.
-template <class Arc>
-void SingleShortestTree(
-    const Fst<Arc> &ifst, MutableFst<Arc> *ofst,
-    const std::vector<std::pair<typename Arc::StateId, size_t>> &parent) {
-  ofst->DeleteStates();
-  ofst->SetInputSymbols(ifst.InputSymbols());
-  ofst->SetOutputSymbols(ifst.OutputSymbols());
-  ofst->SetStart(ifst.Start());
-  for (StateIterator<Fst<Arc>> siter(ifst); !siter.Done(); siter.Next()) {
-    ofst->AddState();
-    ofst->SetFinal(siter.Value(), ifst.Final(siter.Value()));
-  }
-  for (const auto &pair : parent) {
-    if (pair.first != kNoStateId && pair.second != kNoArc) {
-      ArcIterator<Fst<Arc>> aiter(ifst, pair.first);
-      aiter.Seek(pair.second);
-      ofst->AddArc(pair.first, aiter.Value());
-    }
-  }
-  if (ifst.Properties(kError, false)) ofst->SetProperties(kError, kError);
-  ofst->SetProperties(
-      ShortestPathProperties(ofst->Properties(kFstProperties, false), true),
-      kFstProperties);
-}
-
 // Implements the stopping criterion when ShortestPathOptions::first_path
 // is set to true:
 //   operator()(s, d, f) == true
@@ -340,7 +311,7 @@ class ShortestPathCompare {
 template <class Arc, class RevArc>
 void NShortestPath(const Fst<RevArc> &ifst, MutableFst<Arc> *ofst,
                    const std::vector<typename Arc::Weight> &distance,
-                   int32 nshortest, float delta = kShortestDelta,
+                   int32_t nshortest, float delta = kShortestDelta,
                    typename Arc::Weight weight_threshold = Arc::Weight::Zero(),
                    typename Arc::StateId state_threshold = kNoStateId) {
   using StateId = typename Arc::StateId;
@@ -532,7 +503,7 @@ void ShortestPath(const Fst<Arc> &ifst, MutableFst<Arc> *ofst,
 // The weights need to be right distributive and have the path (kPath) property.
 template <class Arc>
 void ShortestPath(const Fst<Arc> &ifst, MutableFst<Arc> *ofst,
-                  int32 nshortest = 1, bool unique = false,
+                  int32_t nshortest = 1, bool unique = false,
                   bool first_path = false,
                   typename Arc::Weight weight_threshold = Arc::Weight::Zero(),
                   typename Arc::StateId state_threshold = kNoStateId,
