@@ -23,11 +23,11 @@
 #define FST_STATE_MAP_H_
 
 #include <algorithm>
+#include <cstdint>
 #include <memory>
 #include <string>
 #include <utility>
 
-#include <fst/types.h>
 #include <fst/log.h>
 
 #include <fst/arc-map.h>
@@ -78,7 +78,7 @@ namespace fst {
 //
 //   // This specifies the known properties of an FST mapped by this
 //   // mapper. It takes as argument the input FST's known properties.
-//   uint64 Properties(uint64 props) const;
+//   uint64_t Properties(uint64_t props) const;
 // };
 //
 // We include a various state map versions below. One dimension of variation is
@@ -287,9 +287,9 @@ class StateMapFstImpl : public CacheImpl<B> {
     CacheImpl<B>::InitArcIterator(state, data);
   }
 
-  uint64 Properties() const override { return Properties(kFstProperties); }
+  uint64_t Properties() const override { return Properties(kFstProperties); }
 
-  uint64 Properties(uint64 mask) const override {
+  uint64_t Properties(uint64_t mask) const override {
     if ((mask & kError) && (fst_->Properties(kError, false) ||
                             (mapper_->Properties(0) & kError))) {
       SetProperties(kError, kError);
@@ -439,7 +439,7 @@ class IdentityStateMapper {
     return MAP_COPY_SYMBOLS;
   }
 
-  uint64 Properties(uint64 props) const { return props; }
+  uint64_t Properties(uint64_t props) const { return props; }
 
  private:
   const Fst<Arc> &fst_;
@@ -503,7 +503,7 @@ class ArcSumMapper {
     return MAP_COPY_SYMBOLS;
   }
 
-  uint64 Properties(uint64 props) const {
+  uint64_t Properties(uint64_t props) const {
     return props & kArcSortProperties & kDeleteArcsProperties &
            kWeightInvariantProperties;
   }
@@ -585,7 +585,7 @@ class ArcUniqueMapper {
     return MAP_COPY_SYMBOLS;
   }
 
-  uint64 Properties(uint64 props) const {
+  uint64_t Properties(uint64_t props) const {
     return props & kArcSortProperties & kDeleteArcsProperties;
   }
 
