@@ -20,8 +20,9 @@
 #ifndef FST_TEST_PROPERTIES_H_
 #define FST_TEST_PROPERTIES_H_
 
+#include <cstdint>
+
 #include <fst/flags.h>
-#include <fst/types.h>
 
 #include <fst/connect.h>
 #include <fst/dfs-visit.h>
@@ -44,20 +45,21 @@ namespace internal {
 // properties can be used. This routine is seldom called directly; instead it is
 // used to implement fst.Properties(mask, /*test=*/true).
 template <class Arc>
-uint64 ComputeProperties(const Fst<Arc> &fst, uint64 mask, uint64 *known) {
+uint64_t ComputeProperties(const Fst<Arc> &fst, uint64_t mask,
+                           uint64_t *known) {
   using Label = typename Arc::Label;
   using StateId = typename Arc::StateId;
   using Weight = typename Arc::Weight;
   const auto fst_props = fst.Properties(kFstProperties, false);  // FST-stored.
   // Computes (trinary) properties explicitly.
   // Initialize with binary properties (already known).
-  uint64 comp_props = fst_props & kBinaryProperties;
+  uint64_t comp_props = fst_props & kBinaryProperties;
   // Computes these trinary properties with a DFS. We compute only those that
   // need a DFS here, since we otherwise would like to avoid a DFS since its
   // stack could grow large.
-  constexpr uint64 kDfsProps = kCyclic | kAcyclic | kInitialCyclic |
-                               kInitialAcyclic | kAccessible | kNotAccessible |
-                               kCoAccessible | kNotCoAccessible;
+  constexpr uint64_t kDfsProps =
+      kCyclic | kAcyclic | kInitialCyclic | kInitialAcyclic | kAccessible |
+      kNotAccessible | kCoAccessible | kNotCoAccessible;
   std::vector<StateId> scc;
   if (mask & (kDfsProps | kWeightedCycles | kUnweightedCycles)) {
     SccVisitor<Arc> scc_visitor(&scc, nullptr, nullptr, &comp_props);
@@ -180,8 +182,8 @@ uint64 ComputeProperties(const Fst<Arc> &fst, uint64 mask, uint64 *known) {
 // Similar to ComputeProperties, but uses the properties already stored
 // in the FST when possible.
 template <class Arc>
-uint64 ComputeOrUseStoredProperties(const Fst<Arc> &fst, uint64 mask,
-                                    uint64 *known) {
+uint64_t ComputeOrUseStoredProperties(const Fst<Arc> &fst, uint64_t mask,
+                                      uint64_t *known) {
   // Check stored FST properties first.
   const auto fst_props = fst.Properties(kFstProperties, /*test=*/false);
   const auto known_props = KnownProperties(fst_props);
@@ -199,7 +201,7 @@ uint64 ComputeOrUseStoredProperties(const Fst<Arc> &fst, uint64 mask,
 // FST_FLAGS_fst_verify_properties is true. This routine is seldom called directly;
 // instead it is used to implement fst.Properties(mask, /*test=*/true).
 template <class Arc>
-uint64 TestProperties(const Fst<Arc> &fst, uint64 mask, uint64 *known) {
+uint64_t TestProperties(const Fst<Arc> &fst, uint64_t mask, uint64_t *known) {
   if (FST_FLAGS_fst_verify_properties) {
     const auto stored_props = fst.Properties(kFstProperties, false);
     const auto computed_props = ComputeProperties(fst, mask, known);
@@ -218,8 +220,8 @@ uint64 TestProperties(const Fst<Arc> &fst, uint64 mask, uint64 *known) {
 // both 'check_mask' and 'test_mask' are computed. This is used to check for
 // newly-added properties that might not be set in old binary files.
 template <class Arc>
-uint64 CheckProperties(const Fst<Arc> &fst, uint64 check_mask,
-                       uint64 test_mask) {
+uint64_t CheckProperties(const Fst<Arc> &fst, uint64_t check_mask,
+                         uint64_t test_mask) {
   auto props = fst.Properties(kFstProperties, false);
   if (FST_FLAGS_fst_verify_properties) {
     props = TestProperties(fst, check_mask | test_mask, /*known=*/nullptr);
