@@ -20,6 +20,9 @@
 #ifndef FST_TEST_FST_TEST_H_
 #define FST_TEST_FST_TEST_H_
 
+#include <memory>
+#include <string>
+
 #include <fst/equal.h>
 #include <fstream>
 #include <fst/matcher.h>
@@ -49,11 +52,9 @@ class FstTester {
       : num_states_(num_states), weighted_(weighted) {
     VectorFst<Arc> vfst;
     InitFst(&vfst, num_states);
-    testfst_ = new F(vfst);
+    testfst_ = std::make_unique<F>(vfst);
   }
 
-  ~FstTester() { delete testfst_; }
-
   // This verifies the contents described in InitFst() using
   // methods defined in a generic Fst.
   template <class G>
@@ -148,12 +149,13 @@ class FstTester {
       }
     }
 
-    G *cfst1 = fst->Copy();
-    cfst1->DeleteStates();
-    CHECK_EQ(cfst1->NumStates(), 0);
-    delete cfst1;
+    {
+      std::unique_ptr<G> cfst1(fst->Copy());
+      cfst1->DeleteStates();
+      CHECK_EQ(cfst1->NumStates(), 0);
+    }
 
-    G *cfst2 = fst->Copy();
+    std::unique_ptr<G> cfst2(fst->Copy());
     for (StateIterator<G> siter(*cfst2); !siter.Done(); siter.Next()) {
       StateId s = siter.Value();
       cfst2->DeleteArcs(s);
@@ -161,10 +163,9 @@ class FstTester {
       CHECK_EQ(cfst2->NumInputEpsilons(s), 0);
       CHECK_EQ(cfst2->NumOutputEpsilons(s), 0);
     }
-    delete cfst2;
   }
 
-  void TestMutable() { TestMutable(testfst_); }
+  void TestMutable() { TestMutable(testfst_.get()); }
 
   // This verifies operator=
   template <class G>
@@ -198,9 +199,8 @@ class FstTester {
     TestBase(c2fst);
 
     // Copy from self
-    const G *c3fst = fst.Copy();
+    std::unique_ptr<const G> c3fst(fst.Copy());
     TestBase(*c3fst);
-    delete c3fst;
   }
 
   void TestCopy() const { TestCopy(*testfst_); }
@@ -214,26 +214,23 @@ class FstTester {
     {
       // write/read
       CHECK(fst.Write(filename));
-      G *ffst = G::Read(filename);
+      auto ffst = fst::WrapUnique(G::Read(filename));
       CHECK(ffst);
       TestBase(*ffst);
-      delete ffst;
     }
 
     {
       // generic read/cast/test
-      Fst<Arc> *gfst = Fst<Arc>::Read(filename);
+      auto gfst = fst::WrapUnique(Fst<Arc>::Read(filename));
       CHECK(gfst);
-      G *dfst = fst::down_cast<G *>(gfst);
+      G *dfst = down_cast<G *>(gfst.get());
       TestBase(*dfst);
 
       // generic write/read/test
       CHECK(gfst->Write(filename));
-      Fst<Arc> *hfst = Fst<Arc>::Read(filename);
+      auto hfst = fst::WrapUnique(Fst<Arc>::Read(filename));
       CHECK(hfst);
       TestBase(*hfst);
-      delete gfst;
-      delete hfst;
     }
 
     {
@@ -249,10 +246,9 @@ class FstTester {
       FstReadOptions opts;
       opts.mode = FstReadOptions::ReadMode("map");
       opts.source = aligned;
-      G *gfst = G::Read(istr, opts);
+      auto gfst = fst::WrapUnique(G::Read(istr, opts));
       CHECK(gfst);
       TestBase(*gfst);
-      delete gfst;
     }
 
     // check mmaping of unaligned files to make sure it does not fail.
@@ -268,29 +264,26 @@ class FstTester {
       FstReadOptions opts;
       opts.mode = FstReadOptions::ReadMode("map");
       opts.source = aligned;
-      G *gfst = G::Read(istr, opts);
+      auto gfst = fst::WrapUnique(G::Read(istr, opts));
       CHECK(gfst);
       TestBase(*gfst);
-      delete gfst;
     }
 
     // expanded write/read/test
     if (fst.Properties(kExpanded, false)) {
-      ExpandedFst<Arc> *efst = ExpandedFst<Arc>::Read(filename);
+      auto efst = fst::WrapUnique(ExpandedFst<Arc>::Read(filename));
       CHECK(efst);
       TestBase(*efst);
       TestExpanded(*efst);
-      delete efst;
     }
 
     // mutable write/read/test
     if (fst.Properties(kMutable, false)) {
-      MutableFst<Arc> *mfst = MutableFst<Arc>::Read(filename);
+      auto mfst = fst::WrapUnique(MutableFst<Arc>::Read(filename));
       CHECK(mfst);
       TestBase(*mfst);
       TestExpanded(*mfst);
-      TestMutable(mfst);
-      delete mfst;
+      TestMutable(mfst.get());
     }
   }
 
@@ -343,7 +336,7 @@ class FstTester {
 
   size_t num_states_ = 0;
   bool weighted_ = true;
-  F *testfst_;  // what we're testing
+  std::unique_ptr<F> testfst_;  // what we're testing
 };
 
 }  // namespace fst
